# This package depends on automagic byte compilation
# https://fedoraproject.org/wiki/Changes/No_more_automagic_Python_bytecompilation_phase_2
%global _python_bytecompile_extra 1

# download path contains version without the last (fourth) digit
%global libo_version 6.4.7
# Should contain .alphaX / .betaX, if this is pre-release (actually
# pre-RC) version. The pre-release string is part of tarball file names,
# so we need a way to define it easily at one place.
%global libo_prerelease %{nil}
# Should contain any suffix of release tarball name, e.g., -buildfix1.
%global libo_buildfix %{nil}
# rhbz#715152 state vendor
%if 0%{?rhel}
%global vendoroption --with-vendor="Red Hat, Inc."
%endif
%if 0%{?fedora}
%global vendoroption --with-vendor="The Fedora Project"
%endif
%global libo_python python3
%global libo_python_executable %{__python3}
%global libo_python_sitearch %{python3_sitearch}
# rhbz#465664 jar-repacking breaks help by reordering META-INF/MANIFEST.MF
%global __jar_repack %{nil}
# make it easier to download sources from pre-release site
%if 0%{?prerelease}
%global source_url http://dev-builds.libreoffice.org/pre-releases/src
%else
%global source_url http://download.documentfoundation.org/libreoffice/src/%{libo_version}
%endif
# URL for external projects' tarballs
%global external_url http://dev-www.libreoffice.org/src
%global girapiversion 0.1

# get english only and no-langpacks for a faster smoketest build
# fedpkg compile/install/local/mockbuild does not handle --without ATM,
# so it is necessary to change this to bcond_with to achieve the same
# effect
%bcond_without langpacks

# remove workdir at the end of %%build, to allow build on space-constrained machines
%ifarch s390 s390x
%bcond_without smallbuild
%else
%bcond_with smallbuild
%endif

# generated by %%langpack definitions
%global langpack_langs %{nil}

%global bundling_options %{nil}

Summary:        Free Software Productivity Suite
Name:           libreoffice
Epoch:          1
Version:        %{libo_version}.2
Release:        19%{?libo_prerelease}%{?dist}
License:        (MPLv1.1 or LGPLv3+) and LGPLv3 and LGPLv2+ and BSD and (MPLv1.1 or GPLv2 or LGPLv2 or Netscape) and Public Domain and ASL 2.0 and MPLv2.0 and CC0
URL:            http://www.libreoffice.org/

Source0:        %{source_url}/libreoffice-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz
Source1:        %{source_url}/libreoffice-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz.asc
Source2:        %{source_url}/libreoffice-help-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz
Source3:        %{source_url}/libreoffice-help-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz.asc
Source4:        %{source_url}/libreoffice-translations-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz
Source5:        %{source_url}/libreoffice-translations-%{version}%{?libo_prerelease}%{?libo_buildfix}.tar.xz.asc
Source6:        gpgkey-C2839ECAD9408FBE9531C3E9F434A1EFAFEEAEA3.gpg.asc
Source7:        http://dev-www.libreoffice.org/extern/185d60944ea767075d27247c3162b3bc-unowinreg.dll
Source8:        libreoffice-multiliblauncher.sh

Source9:        %{external_url}/a7983f859eafb2677d7ff386a023bc40-xsltml_2.1.2.zip
%if 0%{?fedora}
Source10:       %{external_url}/798b2ffdc8bcfe7bca2cf92b62caf685-rhino1_5R5.zip
Source11:       %{external_url}/35c94d2df8893241173de1d16b6034c0-swingExSrc.zip
%endif
#Unfortunately later versions of hsqldb changed the file format, so if we use a later version we loose
#backwards compatability.
Source12:       %{external_url}/17410483b5b5f267aa18b7e00b65e6e0-hsqldb_1_8_0.zip
Source13:       %{external_url}/884ed41809687c3e168fc7c19b16585149ff058eca79acbf3ee784f6630704cc-opens___.ttf
%global bundling_options %{?bundling_options} --without-system-hsqldb

Provides: bundled(hsqldb) = 1.8.0
%if 0%{?fedora}
Provides: bundled(rhino) = 1.5
%endif
Provides: bundled(xsltml) = 2.1.2

# symbolic icons
Source42:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-base-symbolic.svg
Source43:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-calc-symbolic.svg
Source44:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-draw-symbolic.svg
Source45:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-impress-symbolic.svg
Source46:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-main-symbolic.svg
Source47:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-math-symbolic.svg
Source48:       https://raw.githubusercontent.com/gnome-design-team/gnome-icons/master/apps-symbolic/Adwaita/scalable/apps/libreoffice-writer-symbolic.svg

# build tools
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: bc
BuildRequires: binutils
BuildRequires: bison
BuildRequires: desktop-file-utils
BuildRequires: doxygen
BuildRequires: findutils
BuildRequires: flex
BuildRequires: gcc-c++
BuildRequires: gdb
BuildRequires: gettext
BuildRequires: git
BuildRequires: gnupg2
BuildRequires: gperf
BuildRequires: icu
BuildRequires: libtool-ltdl-devel
BuildRequires: make
BuildRequires: mariadb-connector-c-devel
BuildRequires: perl(Digest::MD5)
%if 0%{?fedora}
BuildRequires: glibc-all-langpacks
BuildRequires: libappstream-glib
%endif
BuildRequires: ucpp
BuildRequires: zip

# libs / headers - common
BuildRequires: %{libo_python}-devel
BuildRequires: boost-devel
BuildRequires: cups-devel
BuildRequires: fontpackages-devel
BuildRequires: glm-devel
BuildRequires: hyphen-devel
BuildRequires: libjpeg-turbo-devel
BuildRequires: lpsolve-devel
BuildRequires: openldap-devel
BuildRequires: pam-devel
BuildRequires: pkgconfig(bluez)
BuildRequires: pkgconfig(dbus-glib-1)
BuildRequires: pkgconfig(dconf)
BuildRequires: pkgconfig(epoxy)
BuildRequires: pkgconfig(evolution-data-server-1.2)
BuildRequires: pkgconfig(expat)
BuildRequires: pkgconfig(freetype2)
BuildRequires: pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(gstreamer-1.0)
BuildRequires: pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires: pkgconfig(gtk+-3.0)
BuildRequires: pkgconfig(hunspell)
BuildRequires: pkgconfig(ice)
BuildRequires: pkgconfig(icu-i18n)
BuildRequires: pkgconfig(lcms2)
BuildRequires: pkgconfig(libabw-0.1)
BuildRequires: pkgconfig(libcdr-0.1)
BuildRequires: pkgconfig(libclucene-core)
BuildRequires: pkgconfig(libcmis-0.5)
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libetonyek-0.1)
BuildRequires: pkgconfig(libexttextcat)
BuildRequires: pkgconfig(libfreehand-0.1)
BuildRequires: pkgconfig(libidn)
BuildRequires: pkgconfig(liblangtag)
BuildRequires: pkgconfig(libmspub-0.1)
BuildRequires: pkgconfig(libmwaw-0.3)
BuildRequires: pkgconfig(libodfgen-0.1)
BuildRequires: pkgconfig(libpagemaker-0.0)
BuildRequires: pkgconfig(libpq)
BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(libstaroffice-0.0)
BuildRequires: pkgconfig(libvisio-0.1)
BuildRequires: pkgconfig(libwpd-0.10)
BuildRequires: pkgconfig(libwpg-0.3)
BuildRequires: pkgconfig(libwps-0.4)
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(libxslt)
BuildRequires: pkgconfig(libzmf-0.0)
BuildRequires: pkgconfig(mythes)
BuildRequires: pkgconfig(neon)
BuildRequires: pkgconfig(nss)
BuildRequires: pkgconfig(poppler)
BuildRequires: pkgconfig(poppler-cpp)
BuildRequires: pkgconfig(redland)
BuildRequires: pkgconfig(sane-backends)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xinerama)
BuildRequires: pkgconfig(xmlsec1-nss)
BuildRequires: pkgconfig(xt)
BuildRequires: pkgconfig(zlib)
BuildRequires: unixODBC-devel
BuildRequires: %{libo_python_executable}

# libs / headers - conditional
%if 0%{?fedora}
BuildRequires: pkgconfig(libe-book-0.1)
BuildRequires: qt5-qtbase-devel
BuildRequires: qt5-qtx11extras-devel
BuildRequires: kf5-kconfig-devel
BuildRequires: kf5-kcoreaddons-devel
BuildRequires: kf5-kdelibs4support-devel
BuildRequires: kf5-ki18n-devel
BuildRequires: kf5-kio-devel
BuildRequires: kf5-kwindowsystem-devel
%endif

BuildRequires: gpgmepp-devel
BuildRequires: pkgconfig(cppunit) >= 1.14.0
BuildRequires: pkgconfig(graphite2)
BuildRequires: pkgconfig(harfbuzz)
BuildRequires: pkgconfig(libeot)
BuildRequires: pkgconfig(libepubgen-0.1)
BuildRequires: pkgconfig(libqxp-0.0)
BuildRequires: pkgconfig(liborcus-0.15)
BuildRequires: pkgconfig(mdds-1.5)
BuildRequires: libnumbertext-devel

# java stuff
BuildRequires: ant
%if 0%{?fedora}
BuildRequires: bsh
%endif
BuildRequires: java-devel
BuildRequires: junit
BuildRequires: pentaho-reporting-flow-engine

# fonts needed for tests
BuildRequires: dejavu-sans-fonts
BuildRequires: google-crosextra-carlito-fonts
BuildRequires: liberation-mono-fonts
BuildRequires: liberation-sans-fonts
BuildRequires: liberation-serif-fonts

Requires: %{name}-writer%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-calc%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-impress%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-draw%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-math%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-base%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-emailmerge%{?_isa} = %{epoch}:%{version}-%{release}

# not upstreamed: upstream wants an automatic restart after a crash; we
# want a nice abrt report
Patch0: 0001-don-t-suppress-crashes.patch
# disable tip-of-the-day dialog by default
Patch1: 0001-disble-tip-of-the-day-dialog-by-default.patch
# rhbz#1736810 disable opencl by default again
Patch2: 0001-Resolves-rhbz-1432468-disable-opencl-by-default.patch
# backported
Patch3: 0001-replace-boost-bimap-in-sdext-pdfimport.patch
Patch4: 0001-fix-detecting-qrcodegen.patch
Patch5: 0001-Flatpak-Add-app-bin-libreoffice-app-libreoffice-prog.patch
Patch6: 0001-Restructure-solenv-bin-assemble-flatpak.sh.patch
Patch7: 0001-Related-tdf-127782-resize-the-print-dialog-to-its-op.patch
Patch8: 0001-rhbz-1870501-crash-on-reexport-of-odg.patch
Patch9: 0001-export-HYPERLINK-target-in-html-clipboard-export.patch
Patch10: 0001-use-gdk_wayland_window_set_application_id-when-it-be.patch
Patch11: 0001-tdf-137209-unparent-widgets-in-fragment-dtor.patch
Patch12: 0001-rhbz-1891326-suggest-package-install-of-the-most-app.patch
Patch13: 0001-0.5.1-is-sufficient.patch
Patch14: 0001-munge-cmis-headers-to-remove-exception-specs.patch
Patch15: 0001-1.2.25-is-sufficient.patch
Patch16: 0001-replace-Palatino-Linotype-with-Liberation-Serif.patch
Patch17: 0001-Revert-tdf-69060-lock-refreshing-font-data-when-load.patch
Patch18: 0001-Resolves-rhbz-1893846-if-last-close-had-insert-index.patch
Patch19: 0002-resource-leak.patch
Patch20: 0003-copy_paste_error-data1-looks-like-a-copy-paste-error.patch
Patch21: 0004-Fix-use-of-uninitialized-SwFEShell-bTableCopied.patch
Patch22: 0005-cid-1460969-Uninitialized-scalar-field.patch
Patch23: 0006-tdf-137897-scRetypePassInputDlg-re-allow-password-re.patch
Patch24: 0007-tdf-137982-m_xFrame-is-already-disposed.patch
Patch25: 0008-Resolves-tdf-137215-restore-original-modality-before.patch
Patch26: 0001-rhbz-1882616-move-cursor-one-step-at-a-time-in-the-d.patch
Patch27: 0001-rhbz-1980800-allow-convert-to-csv-to-write-each-shee.patch
Patch28: 0001-Resolves-tdf-132739-two-style-tags-where-there-shoul.patch
Patch29: 0001-backports-to-ease-CVE-backporting.patch
Patch30: 0002-CVE-2021-25635.patch
Patch31: 0003-xmlsecurity-replace-XSecParser-implementation.patch
Patch32: 0004-CVE-2021-25634.patch
Patch33: 0005-CVE-2021-25633.patch
Patch34: 0006-xmlsecurity-replace-OOXMLSecParser-implementation.patch
Patch35: 0001-Correctly-read-PNG-into-bitmaps-N32BitTcA.-formats-w.patch
Patch36: 0001-Read-MOSDocumentLockFile-UTF-16-string-data-with-sam.patch
Patch37: 0001-Convert-attribute-value-to-UTF-8-when-passing-it-to-.patch
Patch38: 0001-Fix-endianness-issues-in-OOX-crypto-routines.patch
Patch39: 0001-CVE-2021-25636.patch
Patch40: 0001-CVE-2022-26305-compare-authors-using-Thumbprint.patch
Patch41: 0002-CVE-2022-26307-make-hash-encoding-match-decoding.patch
Patch42: 0003-CVE-2022-26306-add-Initialization-Vectors-to-passwor.patch
Patch43: 0004-CVE-2022-2630-6-7-add-infobar-to-prompt-to-refresh-t.patch
Patch44: 0001-CVE-2022-3140.patch
Patch45: 0001-CVE-2022-38745.patch
Patch46: 0001-Obtain-actual-0-parameter-count-for-OR-AND-and-1-par.patch
Patch47: 0002-Stack-check-safety-belt-before-fishing-in-muddy-wate.patch
Patch48: 0003-Always-push-a-result-even-if-it-s-only-an-error.patch
Patch49: 0001-set-Referer-on-loading-IFrames.patch
Patch50: 0002-put-floating-frames-under-managed-links-control.patch
Patch51: 0003-assume-IFrame-script-macro-support-isn-t-needed.patch
Patch52: 0001-disable-script-dump.patch
Patch53: 0001-CVE-2023-6185-escape-url-passed-to-gstreamer.patch
Patch54: 0001-CVE-2023-6186-add-some-protocols-that-don-t-make-sense-as-floating.patch
Patch55: 0002-CVE-2023-6186-warn-about-exotic-protocols-as-well.patch
Patch56: 0003-CVE-2023-6186-default-to-ignoring-libreoffice-special-purpose-prot.patch
Patch57: 0004-CVE-2023-6186-reuse-AllowedLinkProtocolFromDocument-in-writer.patch
Patch58: 0005-CVE-2023-6186-reuse-AllowedLinkProtocolFromDocument-in-impress-dra.patch
Patch59: 0006-CVE-2023-6186-backporting.patch
Patch60: 0001-CVE-2024-3044-add-notify-for-script-use.patch
Patch61: 0001-CVE-2024-6472-remove-ability-to-trust-not-validated-macro-signatur.patch
Patch62: 0001-CVE-2025-1080-Filter-out-more-unwanted-command-URIs.patch

%if 0%{?rhel}
# not upstreamed
Patch500: 0001-disable-libe-book-support.patch
%endif

%global instdir %{_libdir}
%global baseinstdir %{instdir}/libreoffice
%global sdkinstdir %{baseinstdir}/sdk
%global datadir %{_datadir}/%{name}
%global fontname opensymbol
# HACK: Get the data dir for -data subpackage. I haven't found any better
# way to do this...
%global oldname %{name}
%global name %{name}-data
%global lodatadocdir %{_pkgdocdir}
%global name %{oldname}

%if 0%{?__isa_bits} == 64
%global mark64 ()(64bit)
%endif

%description
LibreOffice is an Open Source, community-developed, office productivity suite.
It includes the key desktop applications, such as a word processor,
spreadsheet, presentation manager, formula editor and drawing program, with a
user interface and feature set similar to other office suites.  Sophisticated
and flexible, LibreOffice also works transparently with a variety of file
formats, including Microsoft Office File Formats.

%package filters
Summary: All import / export filters
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-calc%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-graphicfilter%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-impress%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-writer%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-xsltfilter%{?_isa} = %{epoch}:%{version}-%{release}

%description filters
Metapackage to pull in all subpackages that contain import or export
filters.

%package core
Summary: Core modules for LibreOffice
Requires: %{name}-%{fontname}-fonts = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
%ifnarch s390 s390x aarch64
Requires: %{name}-plugin%{?_isa} = %{epoch}:%{version}-%{release}
%endif
Requires: liberation-sans-fonts, liberation-serif-fonts, liberation-mono-fonts
Requires: dejavu-sans-fonts, dejavu-serif-fonts, dejavu-sans-mono-fonts
Requires: google-crosextra-caladea-fonts, google-crosextra-carlito-fonts
Requires: %{name}-langpack-en = %{epoch}:%{version}-%{release}
# rhbz#949106 libreoffice-core drags in both openjdk 1.7.0 and 1.8.0
Requires: java-headless >= 1:1.6
Obsoletes: libreoffice-headless < 1:4.4.0.0
Obsoletes: libreoffice-math-debuginfo < 1:6.4.7.2
Provides: libreoffice-headless = %{epoch}:%{version}-%{release}
Provides: libreoffice-headless%{?_isa} = %{epoch}:%{version}-%{release}
%if 0%{?rhel}
Obsoletes: libreoffice-bsh < 1:6.2.2.3
Obsoletes: libreoffice-rhino < 1:6.2.2.3
%endif

%description core
The shared core libraries and support files for LibreOffice.

%package pyuno
Summary: Python support for LibreOffice
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{libo_python_executable}

%description pyuno
Python bindings for the LibreOffice UNO component model. Allows scripts both
external to LibreOffice and within the internal LibreOffice scripting framework
to be written in python.

%package base
Summary: Database front-end for LibreOffice
Requires: pentaho-reporting-flow-engine
Requires: postgresql-jdbc
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-calc%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description base
GUI database front-end for LibreOffice. Allows creation and management of 
databases through a GUI.

%if 0%{?fedora}
%package bsh
Summary: BeanShell support for LibreOffice
Requires: bsh
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}

%description bsh
Support BeanShell scripts in LibreOffice.

%package rhino
Summary: JavaScript support for LibreOffice
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}

%description rhino
Support JavaScript scripts in LibreOffice.
%endif

%package officebean
Summary: JavaBean for LibreOffice Components
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-officebean-common = %{epoch}:%{version}-%{release}

%description officebean
Allows embedding of LibreOffice documents within the Java environment. It
provides a Java AWT window into which the backend LibreOffice process draws
its visual representation

%package officebean-common
Summary: Common JavaBean for LibreOffice Components
Requires: %{name}-data = %{epoch}:%{version}-%{release}
BuildArch: noarch

%description officebean-common
Arch-independent part of %{name}-officebean.

%package wiki-publisher
Summary: Create Wiki articles on MediaWiki servers with LibreOffice
Requires: %{name}-writer%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description wiki-publisher
The Wiki Publisher enables you to create Wiki articles on MediaWiki servers
without having to know the syntax of the MediaWiki markup language. Publish
your new and existing documents transparently with writer to a wiki page.

%package nlpsolver
Summary: Non-linear solver engine for LibreOffice Calc
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-calc%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description nlpsolver
A non-linear solver engine for Calc as an alternative to the default linear
programming model when more complex, nonlinear programming is required.

%package ogltrans
Summary: 3D OpenGL slide transitions for LibreOffice
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description ogltrans
OpenGL Transitions enable 3D slide transitions to be used in LibreOffice.
Requires good quality 3D support for your graphics card for best experience.

%package pdfimport
Summary: PDF Importer for LibreOffice Draw
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description pdfimport
The PDF Importer imports PDF into drawing documents to preserve layout
and enable basic editing of PDF documents.

%package %{fontname}-fonts
Summary: LibreOffice dingbats font
Requires: fontpackages-filesystem
BuildArch: noarch

%description %{fontname}-fonts
A dingbats font, OpenSymbol, suitable for use by LibreOffice for bullets and
mathematical symbols. 

%package writer
Summary: LibreOffice Word Processor Application
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-pdfimport%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description writer
The LibreOffice Word Processor application.

%package emailmerge
Summary: Email mail-merge component for LibreOffice 
Requires: %{name}-writer%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}

%description emailmerge
Enables the LibreOffice writer module to mail-merge to email.

%package calc
Summary: LibreOffice Spreadsheet Application
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-pdfimport%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description calc
The LibreOffice Spreadsheet application.

%package draw
Summary: LibreOffice Drawing Application
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-pdfimport%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-graphicfilter%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description draw
The LibreOffice Drawing Application.

%package impress
Summary: LibreOffice Presentation Application
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-ogltrans%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pdfimport%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-graphicfilter%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description impress
The LibreOffice Presentation Application.

%package math
Summary: LibreOffice Equation Editor Application
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pdfimport%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description math 
The LibreOffice Equation Editor Application.

%package graphicfilter
Summary: LibreOffice Extra Graphic filters
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-data = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description graphicfilter
The graphicfilter module for LibreOffice provides graphic filters, e.g. svg and
flash filters.

%package xsltfilter
Summary: Optional xsltfilter module for LibreOffice
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}

%description xsltfilter
The xsltfilter module for LibreOffice, provides additional docbook and
xhtml export transforms. Install this to enable docbook export.

%package postgresql
Summary: PostgreSQL connector for LibreOffice
Requires: %{name}-base%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description postgresql
A PostgreSQL connector for the database front-end for LibreOffice. Allows
creation and management of PostgreSQL databases through a GUI.

%package ure
Summary: UNO Runtime Environment
#rhbz#1164551 we want to ensure that a libjvm.so of this arch is available
Requires: %{name}-ure-common = %{epoch}:%{version}-%{release}
Requires: unzip%{?_isa}, libjvm.so%{?mark64}

%description ure
UNO is the component model of LibreOffice. UNO offers interoperability between
programming languages, other components models and hardware architectures,
either in process or over process boundaries, in the Intranet as well as in the
Internet. UNO components may be implemented in and accessed from any
programming language for which a UNO implementation (AKA language binding) and
an appropriate bridge or adapter exists

%package ure-common
Summary: Common UNO Runtime Environment
BuildArch: noarch

%description ure-common
Arch-independent part of %{name}-ure.

%package sdk
Summary: Software Development Kit for LibreOffice
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Requires: unzip%{?_isa}, java-devel

%description sdk
The LibreOffice SDK is an add-on for the LibreOffice office suite. It provides
the necessary tools for programming using the LibreOffice APIs and for creating
extensions (UNO components) for LibreOffice.  To set the build environment for
building against the sdk use %{sdkinstdir}/setsdkenv_unix.sh.

%package sdk-doc
Summary: Software Development Kit documentation for LibreOffice

%description sdk-doc
This provides documentation for programming using the LibreOffice APIs
and examples of creating extensions (UNO components) for LibreOffice.

%package glade
Summary: Support for creating LibreOffice dialogs in glade
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}

%description glade
%{name}-glade contains a catalog of LibreOffice-specific widgets for
glade and ui-previewer tool to check the visual appearance of dialogs.

%package librelogo
Summary: LibreLogo scripting language
Requires: %{name}-writer%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-pyuno%{?_isa} = %{epoch}:%{version}-%{release}

%description librelogo
Enables LibreLogo scripting in Writer. LibreLogo is a Logo-like
programming language with interactive vectorgraphics for education and
DTP.

%package data
Summary: LibreOffice data files
BuildArch: noarch

%description data
%{name}-data contains platform-independent data files.

%package x11
Summary: LibreOffice generic X11 support plug-in
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin%{?_isa} = %{epoch}:%{version}-%{release}
Supplements: (%{name}-core%{?_isa} and Xserver)

%description x11
A plug-in for LibreOffice that enables generic X11 support.

%package gtk3
Summary: LibreOffice GTK+ 3 integration plug-in
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Requires: gstreamer1(element-gtksink)%{?mark64}
Obsoletes: libreoffice-gtk2 < 1:6.2.0.0
Obsoletes: libreoffice-gtk2-debuginfo < 1:6.2.0.0
Supplements: (%{name}-core%{?_isa} and gtk3%{?_isa})

%description gtk3
A plug-in for LibreOffice that enables integration into GTK+ 3 environment.

%if 0%{?fedora}

%package kde5
Summary: LibreOffice KDE5 integration plug-in
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: libreoffice-kde4 < 1:6.3.0.0

%description kde5
A plug-in for LibreOffice that enables integration into the KDE5 desktop environment.

%package kf5
Summary: LibreOffice KDE Frameworks 5 integration plug-in
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-ure%{?_isa} = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin = %{epoch}:%{version}-%{release}
Provides: %{name}-plugin%{?_isa} = %{epoch}:%{version}-%{release}
#Supplements: (libreoffice-core and plasma-workspace)

%description kf5
A plug-in for LibreOffice that enables integration into the KDE Frameworks 5.

%endif

%package -n libreofficekit
Summary: A library providing access to LibreOffice functionality
License: MPLv2.0

%description -n libreofficekit
LibreOfficeKit can be used to access LibreOffice functionality
through C/C++, without any need to use UNO.

For now it only offers document conversion (in addition to an
experimental tiled rendering API).

%package -n libreofficekit-devel
Summary: Development files for libreofficekit
Requires: libreofficekit%{?_isa} = %{epoch}:%{version}-%{release}
License: MPLv2.0

%description -n libreofficekit-devel
The libreofficekit-devel package contains libraries and header files for
developing applications that use libreofficekit.

%if 0%{?_enable_debug_packages}

%package gdb-debug-support
Summary: Additional support for debugging with gdb
Requires: gdb%{?_isa}
Requires: %{libo_python}-six
Requires: libreoffice-core%{?_isa} = %{epoch}:%{version}-%{release}
Supplements: libreoffice-debuginfo%{?_isa}

%description gdb-debug-support
This package provides gdb pretty printers for package %{name}.

%files gdb-debug-support
%{_datadir}/gdb/auto-load%{baseinstdir}
%{_datadir}/libreoffice/gdb

%endif

%define _langpack_common(Eg:j:l:) \
%{!-E: \
%{baseinstdir}/program/resource/%{-g:%{-g*}}%{!-g:%{-l*}}/LC_MESSAGES/*.mo  \
%{baseinstdir}/share/registry/res/registry_%{-l*}.xcd \
} \
%{baseinstdir}/share/template/%{-l*} \
%{baseinstdir}/share/registry/Langpack-%{-l*}.xcd \
%{baseinstdir}/share/registry/res/fcfg_langpack_%{-l*}.xcd \
%{baseinstdir}/share/wizards/resources_%{-j:%{-j*}}%{!-j:%{-l*}}.properties \
%{nil}

# Defines a language pack subpackage.
#
# It's necessary to define language code (-l) and language name (-n).
# Additionally, it's possible
# * to require autocorr, hunspell, hyphen or mythes package or font for
#   given language,
# * to provide libreoffice-langpack-loc package, where loc is glibc
#   locale--this is necessary for yum to pick it automatically,
# * to require other, unrelated, packages,
# * to specify file serving as file list.
# For these, lower case character argument takes an argument specifying
# language, upper case character argument uses language from -l.
#
# All remaining arguments are considered to be files and added to the file
# list.
#
# Aa:  autocorr dependency
# c:   additional config file (just the name stem)
# E:   base (US English) langpack
# Ff:  font language dependency
# g:   glibc/java locale
# Hh:  hunspell dependency
# i:   additional language added to this package
# j:   java locale for the additional language
# k:   glibc locale for the additional language
# L:   internal (LibreOffice) language code, used in file names
# l:   language code, e.g., cs
# Mm:  mythes dependency
# n:   language name, e.g., Czech
# p:   Provides: of libreoffice-langpack
# r:   comma-separated list of additional requires
# S:s: script classification (cjk, ctl). -S is only a marker, as it does
#      not add any .xcd into the package (the file does not exist for at
#      least one CTL-using locale, si)
# T    has help files
# Xx:  has autotext definitions
# Yy:  hyphen dependency
#
# Example:
# libreoffice-langpack-cs: langpack for Czech lang. requiring hyphen-cs,
# autocorr-cs, mythes-cs-CZ and suitable font:
# %%langpack -l cs -n Czech -H -A -m cs-CZ
#  b de           q  tu    z BCD  G IJK  N PQR  U    Z0123456789
%define langpack(Aa:c:EFf:g:Hh:i:j:k:L:l:Mm:n:p:r:S:s:TXx:Yy:) \
%define lang %{-l:%{-l*}}%{!-l:%{error:Language code not defined}} \
%define _langpack_lang %{-L:%{-L*}}%{!-L:%{lang}} \
%define pkgname langpack-%{lang} \
%define langname %{-n:%{-n*}}%{!-n:%{error:Language name not defined}} \
\
%global langpack_langs %{langpack_langs} %{_langpack_lang} %{-i:%{-i*}} \
\
%package %{pkgname} \
Summary: %{langname} language pack for LibreOffice \
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release} \
%{-a:Requires: autocorr-%{-a*}}%{!-a:%{-A:Requires: autocorr-%{lang}}} \
%if 0%{?rhel} && 0%{?rhel} < 9 \
%{-f:Requires: font(:lang=%{-f*})}%{!-f:%{-F:Requires: font(:lang=%{lang})}} \
%else \
%{-f:Recommends: langpacks-%{-f*}}%{!-f:%{-F:Recommends: langpacks-%{lang}}} \
%endif \
%{-h:Requires: hunspell-%{-h*}}%{!-h:%{-H:Requires: hunspell-%{lang}}} \
%{-m:Requires: mythes-%{-m*}}%{!-m:%{-M:Requires: mythes-%{lang}}} \
%{-y:Requires: hyphen-%{-y*}}%{!-y:%{-Y:Requires: hyphen-%{lang}}} \
%{-r:Requires: %{-r*}} \
%{-p:Provides: %{name}-langpack-%{-p*} = %{epoch}:%{version}-%{release}} \
%{-p:Provides: %{name}-langpack-%{-p*}%{?_isa} = %{epoch}:%{version}-%{release}} \
%{-p:Supplements: (%{name}-core%{?_isa} and langpacks-%{-p*})} \
%{!-p:Supplements: (%{name}-core%{?_isa} and langpacks-%{lang})} \
%if 0%{?rhel} \
%{-T:Requires: %{name}-help-%{lang}} \
%else \
%{-T:Recommends: %{name}-help-%{lang}} \
%endif \
\
%description %{pkgname} \
Provides additional %{langname} translations and resources for LibreOffice. \
\
%{-T: \
%package help-%{lang} \
Summary: %{langname} help for LibreOffice \
Requires: %{name}-core%{?_isa} = %{epoch}:%{version}-%{release} \
\
%description help-%{lang} \
Provides %{langname} help for LibreOffice. \
\
%files help-%{lang} \
%docdir %{baseinstdir}/help/%{_langpack_lang} \
%{baseinstdir}/help/%{_langpack_lang} \
} \
\
%files %{pkgname} \
%{expand:%%_langpack_common %{-E} -l %{_langpack_lang} %{-g:-g %{-g*} -j %{-g*}}} \
%{-x:%{baseinstdir}/share/autotext/%{-x*}}%{!-x:%{-X:%{baseinstdir}/share/autotext/%{_langpack_lang}}} \
%{-c:%{baseinstdir}/share/registry/%{-c*}.xcd} \
%{-s:%{baseinstdir}/share/registry/%{-s*}_%{_langpack_lang}.xcd} \
%{-i:%{expand:%%_langpack_common %{-E} -l %{-i*} %{-k:-g %{-k*}} %{-j:-j %{-j*}}}} \
%{nil}

# Defines an auto-correction subpackage.
#
# i: add autocorrections from additional language
# l: language code
# n: language name
# L  the filename does not contain country code
#
# All remaining arguments are considered to be files and added to the file
# list.
%define autocorr(i:Ll:n:) \
%define lang %{-l:%{-l*}}%{!-l:%{error:Language code not defined}} \
%define pkgname autocorr-%{lang} \
%define langname %{-n:%{-n*}}%{!-n:%{error:Language name not defined}} \
\
%package -n %{pkgname} \
Summary: %{langname} auto-correction rules \
BuildArch: noarch \
\
%description -n %{pkgname} \
Rules for auto-correcting common %{langname} typing errors. \
\
%files -n %{pkgname} \
%doc instdir/LICENSE \
%dir %{_datadir}/autocorr \
%{-L:%{_datadir}/autocorr/acor_%{lang}.dat} \
%{!-L:%{_datadir}/autocorr/acor_%{lang}-*.dat} \
%{nil}

%langpack -l en -n English -F -h en-US -Y -M -A -E -L en-US -T -X -g en_US

%if %{with langpacks}

%langpack -l af -n Afrikaans -F -H -Y -A -X
%langpack -l ar -n Arabic -F -H -s ctl -T -X
%langpack -l as -n Assamese -F -H -Y -X
%langpack -l bg -n Bulgarian -F -H -Y -M -A -T -X
%langpack -l bn -n Bengali -F -H -Y -T -X
%langpack -l br -n Breton -F -H -X
%langpack -l ca -n Catalan -F -H -Y -M -A -T -X
%langpack -l cs -n Czech -F -H -Y -M -A -T -X
%langpack -l cy -n Welsh -F -H -Y -X
%langpack -l da -n Danish -F -H -Y -M -A -T -X
%langpack -l de -n German -F -H -Y -M -A -T -X
%langpack -l dz -n Dzongkha -F -s ctl -T -X
%langpack -l el -n Greek -F -H -Y -M -T -X
%langpack -l es -n Spanish -F -H -Y -M -A -T -X
%langpack -l et -n Estonian -F -H -Y -T -X
%langpack -l eu -n Basque -F -H -Y -T -X
%langpack -l fa -n Farsi -A -H -Y -s ctl -X
%langpack -l fi -n Finnish -F -r libreoffice-voikko -A -T -X
%langpack -l fr -n French -F -H -Y -M -A -T -X
%langpack -l ga -n Irish -F -H -Y -M -A -X
%langpack -l gl -n Galician -F -H -Y -T -X
%langpack -l gu -n Gujarati -F -H -Y -s ctl -T -X
%langpack -l he -n Hebrew -F -H -s ctl -T -X
%langpack -l hi -n Hindi -F -H -Y -s ctl -T -X
%langpack -l hr -n Croatian -F -H -Y -A -T -X
%langpack -l hu -n Hungarian -F -H -Y -M -A -T -X
%{baseinstdir}/share/wordbook/hu_AkH11.dic
%langpack -l id -n Indonesian -F -H -Y -T -X
%langpack -l it -n Italian -F -H -Y -M -A -T -X
%langpack -l ja -n Japanese -F -A -s cjk -T -X
%langpack -l kk -n Kazakh -F -H -X
%langpack -l kn -n Kannada -F -H -Y -X
%langpack -l ko -n Korean -F -H -A -s cjk -T -X
%langpack -l lt -n Lithuanian -F -H -Y -A -T -X
%langpack -l lv -n Latvian -F -H -Y -M -T -X
%langpack -l mai -n Maithili -F -X
%langpack -l ml -n Malayalam -F -H -Y -X
%langpack -l mr -n Marathi -F -H -Y -X
%langpack -l nb -n Bokmal -F -H -Y -M -T -X
%langpack -l nl -n Dutch -F -H -Y -M -A -T -X -X
%langpack -l nn -n Nynorsk -F -H -Y -M -T
%define langpack_lang Southern Ndebele
%langpack -l nr -n %{langpack_lang} -F -H -X
%define langpack_lang Northern Sotho
%langpack -l nso -n %{langpack_lang} -F -H -X
%langpack -l or -n Odia -F -H -Y -s ctl -X
%langpack -l pa -n Punjabi -F -H -Y -s ctl -L pa-IN -g pa_IN -X
%langpack -l pl -n Polish -F -H -Y -M -A -T -X
%define langpack_lang Brazilian Portuguese
%langpack -l pt-BR -n %{langpack_lang} -f pt -h pt -y pt -m pt -a pt -p pt_BR -T -X -g pt_BR
%langpack -l pt-PT -n Portuguese -f pt -h pt -y pt -m pt -a pt -p pt_PT -T -L pt -x pt
%langpack -l ro -n Romanian -A -F -H -Y -M -T -X
%langpack -l ru -n Russian -F -H -Y -M -A -T -X
%langpack -l si -n Sinhalese -F -H -S ctl -T -X
%langpack -l sk -n Slovak -F -H -Y -M -A -T -X
%langpack -l sl -n Slovenian -F -H -Y -M -A -T -X
%{baseinstdir}/share/wordbook/sl.dic

#rhbz#452379 clump serbian translations together
%langpack -l sr -n Serbian -F -H -Y -A -i sr-Latn -k sr@latin -j sr_Latn -x sr*
%langpack -l ss -n Swati -F -H -X
%define langpack_lang Southern Sotho
# note that langpacks-st seems to be missing as of the time of writing, so no -F here
%langpack -l st -n %{langpack_lang} -H -X
%langpack -l sv -n Swedish -F -H -Y -M -A -T -X
%langpack -l ta -n Tamil -F -H -Y -s ctl -T -X
%langpack -l te -n Telugu -F -H -Y -X
%langpack -l th -n Thai -F -H -s ctl -c ctlseqcheck_th -X
%langpack -l tn -n Tswana -F -H -X
%langpack -l tr -n Turkish -F -A -T -X
%langpack -l ts -n Tsonga -F -H -X
%langpack -l uk -n Ukrainian -F -H -Y -M -T -X
%langpack -l ve -n Venda -F -H -X
%langpack -l xh -n Xhosa -F -H -X
%define langpack_lang Simplified Chinese
%langpack -l zh-Hans -n %{langpack_lang} -f zh-cn -a zh -p zh_CN -s cjk -T -L zh-CN -x zh-CN -g zh_CN
%define langpack_lang Traditional Chinese
%langpack -l zh-Hant -n %{langpack_lang} -f zh-tw -a zh -p zh_TW -s cjk -T -L zh-TW -x zh-TW -g zh_TW
%langpack -l zu -n Zulu -F -H -Y -X
%undefine langpack_lang

%endif

%autocorr -l en -n English

%if %{with langpacks}

%autocorr -l af -n Afrikaans
%autocorr -l bg -n Bulgarian
%autocorr -l ca -n Catalan
%autocorr -l cs -n Czech
%autocorr -l da -n Danish
%autocorr -l de -n German -L
%define autocorr_lang Lower Sorbian
%autocorr -l dsb -n %{autocorr_lang} -L
%autocorr -l el -n Greek
%autocorr -l es -n Spanish -L
%autocorr -l fa -n Farsi
%autocorr -l fi -n Finnish
%autocorr -l fr -n French -L
%autocorr -l ga -n Irish
%autocorr -l hr -n Croatian
%define autocorr_lang Upper Sorbian
%autocorr -l hsb -n %{autocorr_lang} -L
%autocorr -l hu -n Hungarian
%autocorr -l is -n Icelandic
%autocorr -l it -n Italian -L
%autocorr -l ja -n Japanese
%autocorr -l ko -n Korean
%autocorr -l lb -n Luxembourgish
%autocorr -l lt -n Lithuanian
%autocorr -l mn -n Mongolian
%autocorr -l nl -n Dutch
%autocorr -l pl -n Polish
%autocorr -l pt -n Portuguese
%autocorr -l ro -n Romanian
%autocorr -l ru -n Russian
%autocorr -l sk -n Slovak
%autocorr -l sl -n Slovenian
%autocorr -l sr -n Serbian
%autocorr -l sv -n Swedish
%autocorr -l tr -n Turkish
%autocorr -l vi -n Vietnamese
%autocorr -l zh -n Chinese

%endif

%define make_autocorr_aliases(l:) \
%{?-l: \
for lang in %{*}; do \
    ln -sf acor_%{-l*}.dat acor_$lang.dat \
done \
} \
%{!?-l:%{error:-l must be present}}

%prep
# verify tarballs
gpg2 --dearmor < %{SOURCE6} > keyring.gpg
gpgv2 --keyring ./keyring.gpg %{SOURCE1} %{SOURCE0}
gpgv2 --keyring ./keyring.gpg %{SOURCE3} %{SOURCE2}
gpgv2 --keyring ./keyring.gpg %{SOURCE5} %{SOURCE4}

%setup -q -n %{name}-%{version}%{?libo_prerelease} -b 2 -b 4
rm -rf git-hooks */git-hooks

# set up git repo
git init
git config user.name rpmbuild
git config user.email rpmbuild@fedoraproject.org
git config gc.auto 0 # disable auto packing
git add -A
git commit -q -a -m %{name}-%{version}

#Customize Palette to add Red Hat colours
(head -n -1 extras/source/palettes/standard.soc && \
 echo -e '  <draw:color draw:name="Red Hat 1" draw:color="#cc0000"/>
  <draw:color draw:name="Red Hat 2" draw:color="#0093d9"/>
  <draw:color draw:name="Red Hat 3" draw:color="#ff8d00"/>
  <draw:color draw:name="Red Hat 4" draw:color="#abb400"/>
  <draw:color draw:name="Red Hat 5" draw:color="#4e376b"/>' && \
 tail -n 1 extras/source/palettes/standard.soc) > redhat.soc
mv -f redhat.soc extras/source/palettes/standard.soc
git commit -q -a -m 'add Red Hat colors to palette'

# apply patches
git am %{patches}

sed -i -e /CppunitTest_sw_ooxmlexport7/d sw/Module_sw.mk # i686
sed -i -e /CppunitTest_sc_array_functions_test/d sc/Module_sc.mk # ppc64le
sed -i -e /CppunitTest_sw_ww8export/d sw/Module_sw.mk
sed -i -e /CppunitTest_sc_addin_functions_test/d sc/Module_sc.mk # aarch64/ppc64*/s390x
sed -i -e /CppunitTest_sc_financial_functions_test/d sc/Module_sc.mk # ppc64*
sed -i -e /CppunitTest_sc_statistical_functions_test/d sc/Module_sc.mk # aarch64/ppc64*
sed -i -e /CppunitTest_dbaccess_hsqldb_test/d dbaccess/Module_dbaccess.mk # i686
sed -i -e s/CppunitTest_dbaccess_RowSetClones// dbaccess/Module_dbaccess.mk # i686
sed -i -e /CppunitTest_services/d postprocess/Module_postprocess.mk # i686
sed -i -e /CppunitTest_sd_export_ooxml2/d sd/Module_sd.mk # i686
sed -i -e /CppunitTest_sw_ooxmlexport4/d sw/Module_sw.mk
sed -i -e /CppunitTest_xmlsecurity_signing/d xmlsecurity/Module_xmlsecurity.mk
%if 0%{?rhel}
sed -i -e /CppunitTest_desktop_lib/d desktop/Module_desktop.mk
sed -i -e s/CppunitTest_editeng_core// editeng/Module_editeng.mk
sed -i -e /CppunitTest_writerperfect_draw/d writerperfect/Module_writerperfect.mk
sed -i -e /CppunitTest_sw_ooxmlimport/d sw/Module_sw.mk
sed -i -e /CppunitTest_sw_ooxmlexport10/d sw/Module_sw.mk
sed -i -e /CppunitTest_sw_uiwriter/d sw/Module_sw.mk
sed -i -e /CppunitTest_sc_subsequent_filters_test/d sc/Module_sc.mk
%endif
sed -i -e /CppunitTest_sal_osl/d sal/Module_sal.mk
%ifarch s390x
sed -i -e /CppunitTest_dbaccess_hsqlbinary_import/d dbaccess/Module_dbaccess.mk
sed -i -e /CppunitTest_vcl_svm_test/d vcl/Module_vcl.mk
sed -i -e /CustomTarget_uno_test/d testtools/Module_testtools.mk
sed -i -e /CppunitTest_sw_htmlexport/d sw/Module_sw.mk
%endif
# Broken with system nss. See also upstream commit ac519af951541b7313a4c98e1bee463bf47356be
sed -i -e '/^\s*CPPUNIT_TEST(testInsertCertificate_PEM_ODT);/d' desktop/qa/desktop_lib/test_desktop_lib.cxx
sed -i -e '/^\s*CPPUNIT_TEST(testInsertCertificate_PEM_DOCX);/d' desktop/qa/desktop_lib/test_desktop_lib.cxx

git commit -q -a -m 'temporarily disable failing tests'

# Seeing .git dir makes some of the build tools change their behavior.
# We do not want that. Note: it is still possible to use
# git --git-dir=.git-rpm
mv .git .git-rpm

%build
# path to external tarballs
EXTSRCDIR=`dirname %{SOURCE0}`

#use the RPM_OPT_FLAGS but remove the OOo overridden ones
for i in $RPM_OPT_FLAGS; do
        case "$i" in
                -pipe|-Wall|-Werror*|-fexceptions) continue;;
        esac
        ARCH_FLAGS="$ARCH_FLAGS $i"
done
%ifarch s390 aarch64
# these builders typically do not have enough memory to link the big libs with -g2
ARCH_FLAGS="$ARCH_FLAGS -g1"
%endif
export ARCH_FLAGS
export CFLAGS=$ARCH_FLAGS
export CXXFLAGS=$ARCH_FLAGS

%if 0%{?rhel}
%define distrooptions --disable-eot --disable-scripting-beanshell --disable-scripting-javascript
%else
# fedora
%define distrooptions --enable-eot --enable-kde5 --enable-gtk3-kde5
%endif

%if %{with langpacks}
%define with_lang --with-lang='%{langpack_langs}'
%endif

aclocal -I m4
autoconf

SMP_MFLAGS=%{?_smp_mflags}
SMP_MFLAGS=$[${SMP_MFLAGS/-j/}]

%if 0%{?flatpak}
%define flatpakoptions --with-boost-libdir=%{_libdir} --with-beanshell-jar=/app/share/java/bsh.jar --with-commons-logging-jar=/app/share/java/commons-logging.jar --with-external-dict-dir=/app/share/myspell --with-external-hyph-dir=/app/share/hyphen --with-external-thes-dir=/app/share/mythes --with-flute-jar=/app/share/java/flute.jar --with-jdk-home=/app/lib/jvm/java-1.8.0-openjdk --with-jfreereport-jar=/app/share/java/flow-engine.jar --with-libbase-jar=/app/share/java/libbase.jar --with-libfonts-jar=/app/share/java/libfonts.jar --with-libformula-jar=/app/share/java/libformula.jar --with-liblayout-jar=/app/share/java/liblayout.jar --with-libloader-jar=/app/share/java/libloader.jar --with-librepository-jar=/app/share/java/librepository.jar --with-libserializer-jar=/app/share/java/libserializer.jar --with-libxml-jar=/app/share/java/libxml.jar --with-sac-jar=/app/share/java/sac.jar FIREBIRDCONFIG=%{_libdir}/fb_config QT4INC=%{_includedir}
%endif

# TODO: enable coinmp?
# avoid running autogen.sh on make
touch autogen.lastrun
%configure \
 %vendoroption \
 %{?with_lang} \
 --with-parallelism=$SMP_MFLAGS \
 --disable-coinmp \
 --disable-fetch-external \
 --disable-openssl \
 --disable-firebird-sdbc \
 --disable-pdfium \
 --disable-qrcodegen \
 --enable-dconf \
 --enable-evolution2 \
 --enable-ext-nlpsolver \
 --enable-ext-wiki-publisher \
 --enable-gtk3 \
 --enable-introspection \
 --enable-release-build \
 --enable-scripting-beanshell \
 --enable-scripting-javascript \
 --enable-symbols \
 --with-build-version="%{version}-%{release}" \
 --with-external-dict-dir=/usr/share/myspell \
 --with-external-tar="$EXTSRCDIR" \
 --with-help \
 --with-system-dicts \
 --with-system-libs \
 --without-export-validation \
 --without-fonts \
 --without-lxml \
 --with-gdrive-client-secret="GYWrDtzyZQZ0_g5YoBCC6F0I" \
 --with-gdrive-client-id="457862564325.apps.googleusercontent.com" \
 --enable-python=system \
 --with-system-ucpp \
 %{distrooptions} \
 %{?bundling_options} \
 %{?archoptions} \
 %{?flatpakoptions}

ulimit -c unlimited || true

if ! make verbose=true build-nocheck; then
    echo "build attempt 1 failed"
    if ! make verbose=true build-nocheck; then
        echo "build attempt 2 failed"
        make verbose=true GMAKE_OPTIONS=-rj1 build-nocheck
    fi
fi

#generate the icons and mime type stuff
export DESTDIR=../output
export KDEMAINDIR=/usr
export GNOMEDIR=/usr
export GNOME_MIME_THEME=hicolor
export PREFIXDIR=/usr
# TODO use empty variables? Should make the renaming hacks in %%install
# unnecessary.
. ./bin/get_config_variables PRODUCTVERSIONSHORT PRODUCTVERSION SRCDIR WORKDIR PKG_CONFIG INSTDIR
pushd $WORKDIR/CustomTarget/sysui/share/libreoffice
./create_tree.sh
popd
mkdir $WORKDIR/os-integration
cp -pr $WORKDIR/CustomTarget/sysui/share/output/usr/share/* $WORKDIR/os-integration
cp -pr $WORKDIR/CustomTarget/sysui/share/libreoffice/LOKDocView-%{girapiversion}.* $WORKDIR/os-integration

%if %{with smallbuild}
# remove the biggest offenders
# NOTE: not removing complete LinkTarget, as some libs are needed for smoketest
rm -rf $WORKDIR/CxxObject $WORKDIR/GenCxxObject $WORKDIR/HelpTarget $WORKDIR/LinkTarget/CppunitTest
%endif


%install
# TODO investigate use of make distro-pack-install
#figure out the icon version
. ./bin/get_config_variables PRODUCTVERSIONSHORT PRODUCTVERSION SRCDIR WORKDIR
export PRODUCTVERSIONSHORT PRODUCTVERSION

# installation

install -m 0755 -d %{buildroot}%{instdir}
if ! make instsetoo_native PKGFORMAT=installed DISABLE_STRIP=1 EPM=not-used-but-must-be-set; then
    echo - ---dump log start---
    cat $WORKDIR/installation/LibreOffice/installed/logging/en-US/log_*_en-US.log
    echo - ---dump log end---
    echo - ---dump log start -- SDK---
    cat $WORKDIR/installation/LibreOffice_SDK/installed/logging/en-US/log_*_en-US.log
    echo - ---dump log end -- SDK---
    echo - ---dump log start -- languagepacks---
    cat $WORKDIR/installation/LibreOffice_languagepack/installed/logging/en-US/log_*_en-US.log
    echo - ---dump log end -- languagepacks---
    exit 1
fi
install -m 0755 -d %{buildroot}%{baseinstdir}
mv $WORKDIR/installation/LibreOffice/installed/install/en-US/* %{buildroot}%{baseinstdir}
%if %{with langpacks}
for langpack in $WORKDIR/installation/LibreOffice_languagepack/installed/install/*; do
  [ `basename $langpack` = log ] && continue
  cp -rp $langpack/* %{buildroot}%{baseinstdir}
  rm -rf $langpack
done
%endif
mv $WORKDIR/installation/LibreOffice_SDK/installed/install/en-US/sdk %{buildroot}%{sdkinstdir}
chmod -R +w %{buildroot}%{baseinstdir}

# postprocessing and tweaks

# The installer currently sets UserInstallation to
# $ORIGIN/../libreoffice/4, which is of course total nonsense. Because I
# have no inclination to crawl through mountains of perl code to figure out
# where it comes from, I am just going to replace it by a sensible
# value here.
sed -i -e '/UserInstallation/s@\$ORIGIN/..@$SYSUSERCONFIG@' %{buildroot}%{baseinstdir}/program/bootstraprc

#configure sdk
pushd %{buildroot}%{sdkinstdir}
    sed -e "s,@OO_SDK_NAME@,sdk," \
        -e "s,@OO_SDK_HOME@,%{sdkinstdir}," \
        -e "s,@OFFICE_HOME@,%{baseinstdir}," \
        -e "s,@OO_SDK_MAKE_HOME@,/usr/bin," \
        -e "s,@OO_SDK_ZIP_HOME@,/usr/bin," \
        -e "s,@OO_SDK_CPP_HOME@,/usr/bin," \
        -e "s,@OO_SDK_CAT_HOME@,/usr/bin," \
        -e "s,@OO_SDK_SED_HOME@,/usr/bin," \
        -e "s,@OO_SDK_CC_55_OR_HIGHER@,," \
        -e "s,@OO_SDK_JAVA_HOME@,$JAVA_HOME," \
        -e "s,@OO_SDK_OUTPUT_DIR@,\$HOME," \
        -e "s,@SDK_AUTO_DEPLOYMENT@,NO," \
        setsdkenv_unix.sh.in > setsdkenv_unix.sh
    # ensure no unexpanded vars sneaked in
    grep '@[A_Z0-9_]\+@' setsdkenv_unix.sh && exit 1
    chmod 755 setsdkenv_unix.sh
    # we don't want to install the input file
    rm -f setsdkenv_unix.sh.in
# TODO: is this still necessary?
#fix permissions
    find examples -type f -exec chmod -x {} \;
popd

#ensure a template dir for each lang
pushd %{buildroot}%{baseinstdir}/share/template
for I in %{langpack_langs}; do
    mkdir -p $I
done
popd

#Set some aliases to canonical autocorrect language files for locales with matching languages
pushd %{buildroot}%{baseinstdir}/share/autocorr

%make_autocorr_aliases -l en-GB en-AG en-AU en-BS en-BW en-BZ en-CA en-DK en-GH en-HK en-IE en-IN en-JM en-NG en-NZ en-SG en-TT
%make_autocorr_aliases -l en-US en-PH
#en-ZA exists and has a good autocorrect file with two or three extras that make sense for 
#neighbouring english speaking territories
%make_autocorr_aliases -l en-ZA en-NA en-ZW
%if %{with langpacks}
%make_autocorr_aliases -l af-ZA af-NA
%make_autocorr_aliases -l nl-NL nl-AW
%make_autocorr_aliases -l sv-SE sv-FI
%else
rm -f acor_[a-df-z]*.dat acor_e[lsu]*.dat
%endif
popd
#rhbz#484055 make these shared across multiple applications
install -m 0755 -d %{buildroot}%{_datadir}
mv -f %{buildroot}%{baseinstdir}/share/autocorr %{buildroot}%{_datadir}/autocorr
chmod 755 %{buildroot}%{_datadir}/autocorr
ln -s %{_datadir}/autocorr %{buildroot}%{baseinstdir}/share/autocorr

#remove it in case we didn't build with gcj
rm -f %{buildroot}%{baseinstdir}/program/classes/sandbox.jar
# we don't need this in the install
rm -f %{buildroot}%{baseinstdir}/program/classes/smoketest.jar

#remove dummy .dat files
rm -f %{buildroot}%{baseinstdir}/program/root?.dat

#set standard permissions for rpmlint
find %{buildroot}%{baseinstdir} -exec chmod +w {} \;
find %{buildroot}%{baseinstdir} -type d -exec chmod 0755 {} \;

# move python bits into site-packages
install -m 0755 -d %{buildroot}%{libo_python_sitearch}
pushd %{buildroot}%{libo_python_sitearch}
echo "import sys, os" > uno.py
echo "sys.path.append('%{baseinstdir}/program')" >> uno.py
echo "os.putenv('URE_BOOTSTRAP', 'vnd.sun.star.pathname:%{baseinstdir}/program/fundamentalrc')" >> uno.py
cat %{buildroot}%{baseinstdir}/program/uno.py >> uno.py
rm -f %{buildroot}%{baseinstdir}/program/uno.py*
mv -f %{buildroot}%{baseinstdir}/program/unohelper.py* .
mv -f %{buildroot}%{baseinstdir}/program/officehelper.py* .
popd

# rhbz#477435 package opensymbol separately
pushd %{buildroot}%{baseinstdir}/share/fonts/truetype
install -d -m 0755 %{buildroot}%{_fontdir}
install -p -m 0644 *.ttf %{buildroot}%{_fontdir}
popd
rm -rf %{buildroot}%{baseinstdir}/share/fonts/truetype/*.ttf

# move platform-independent data into shared dir
install -m 0755 -d %{buildroot}%{datadir}
rm -f %{buildroot}%{baseinstdir}/CREDITS.fodt %{buildroot}%{baseinstdir}/LICENSE* %{buildroot}%{baseinstdir}/NOTICE
# rhbz#1473749 ensure display of files in license/about dialogs works
ln -sr %{buildroot}%{lodatadocdir}/CREDITS.fodt %{buildroot}%{baseinstdir}/CREDITS.fodt
ln -sr %{buildroot}%{lodatadocdir}/LICENSE.html %{buildroot}%{baseinstdir}/LICENSE.html

#ensure that no sneaky un-prelinkable, un-fpic or non executable shared libs 
#have snuck through
pic=0
executable=0
for foo in `find %{buildroot}%{instdir} -name "*" -exec file {} \;| grep ": ELF" | cut -d: -f 1` ; do
    chmod +wx $foo
    ls -asl $foo
    result=`readelf -d $foo | grep TEXTREL` || true
    if [ "$result" != "" ]; then
        echo "TEXTREL Warning: $foo is b0rked (-fpic missing)"
        pic=1
    fi
    result=`readelf -l $foo | grep GNU_STACK | grep RWE` || true
    if [ "$result" != "" ]; then
        echo "GNU_STACK Warning: $foo is b0rked (-noexecstack missing)"
        executable=1
    fi
done
if [ $pic == 1 ]; then false; fi
if [ $executable == 1 ]; then false; fi

#make up some /usr/bin scripts
install -m 0755 -d %{buildroot}%{_bindir}

pushd %{buildroot}%{_bindir}
echo \#\!/bin/sh > ooffice
echo exec libreoffice \"\$@\" >> ooffice
chmod a+x ooffice

echo \#\!/bin/sh > ooviewdoc
echo exec libreoffice --view \"\$@\" >> ooviewdoc
chmod a+x ooviewdoc

for app in base calc draw impress math writer; do
    echo \#\!/bin/sh > oo$app
    echo exec libreoffice --$app \"\$@\" >> oo$app
    chmod a+x oo$app
done

sed -e s/LAUNCHER/unopkg/g -e s/BRAND/libreoffice/g %{SOURCE8} > unopkg
chmod a+x unopkg

sed -e s/LAUNCHER/soffice/g -e s/BRAND/libreoffice/g %{SOURCE8} > libreoffice
chmod a+x libreoffice

%if 0%{?flatpak}
sed -i -e 's|/usr/lib|/app/lib|g' unopkg libreoffice
%endif

# rhbz#499474 provide a /usr/bin/soffice for .recently-used.xbel
ln -s %{baseinstdir}/program/soffice soffice
# rhbz#499474 provide a /usr/bin/openoffice.org for backwards compat
ln -s libreoffice openoffice.org
popd

pushd %{buildroot}%{baseinstdir}/share/xdg/
chmod u+w *.desktop
ICONVERSION=`echo $PRODUCTVERSION | sed -e 's/\.//'`
for file in *.desktop; do
    # rhbz#156677 remove the version from Name=
    # rhbz#156067 don't version the icons
    sed -i -e "s/ *$PRODUCTVERSION//g" \
        -e "s/$ICONVERSION//g" \
        -e "s/$PRODUCTVERSIONSHORT//g" \
        $file
done
# rhbz#186515 do not show startcenter
desktop-file-edit --set-key=NoDisplay --set-value=true startcenter.desktop
%ifarch s390 s390x aarch64
for app in base calc draw impress math startcenter writer xsltfilter; do
    desktop-file-edit --set-key=NoDisplay --set-value=true $app.desktop
done
%endif
# relocate the .desktop and icon files
install -m 0755 -d %{buildroot}%{_datadir}/applications
for app in base calc draw impress math startcenter writer xsltfilter; do
    sed -i -e 's/\${UNIXBASISROOTNAME}/%{name}/' $app.desktop
    desktop-file-validate $app.desktop
    install -m 0644 -p $app.desktop %{buildroot}%{_datadir}/applications/libreoffice-$app.desktop
done
popd
%if 0%{?flatpak}
# Transform the libreoffice-*.desktop files into
# org.libreoffice.LibreOffice.*.desktop ones:
solenv/bin/assemble-flatpak-desktop.sh %{buildroot}%{_datadir}/applications/ \
 %{buildroot}%{_datadir}/applications/
rm %{buildroot}%{_datadir}/applications/libreoffice-*.desktop
%endif

pushd $WORKDIR/os-integration
#get rid of the gnome icons and other unneeded files
rm -rf icons/gnome applications application-registry

#relocate the rest of them
# rhbz#901346 512x512 icons are not used by anything
for icon in `find icons -path '*/512x512' -prune -o -type f -print`; do
    install -m 0755 -d %{buildroot}%{_datadir}/`dirname $icon`
    install -m 0644 -p $icon %{buildroot}%{_datadir}/`echo $icon | sed -e s@libreoffice$ICONVERSION-@libreoffice-@ | sed -e s@libreoffice$PRODUCTVERSION-@libreoffice-@`
done
install -m 0755 -d %{buildroot}%{_datadir}/mime-info
install -m 0644 -p mime-info/libreoffice$PRODUCTVERSION.keys %{buildroot}%{_datadir}/mime-info/libreoffice.keys
install -m 0644 -p mime-info/libreoffice$PRODUCTVERSION.mime %{buildroot}%{_datadir}/mime-info/libreoffice.mime
#add our mime-types, e.g. for .oxt extensions
install -m 0755 -d %{buildroot}%{_datadir}/mime/packages
install -m 0644 -p mime/packages/libreoffice$PRODUCTVERSION.xml %{buildroot}%{_datadir}/mime/packages/libreoffice.xml

%if 0%{?fedora}
# restrict abipkgdiff to shared objects that actually have a stable ABI
for pkg in core base officebean ogltrans pdfimport calc writer impress graphicfilter postgresql ure pyuno x11 gtk3 kde5 libreofficekit; do
    cat > %{buildroot}%{baseinstdir}/program/${pkg}.abignore << _EOF
[suppress_file]
file_name_not_regexp=.*\.so\.[0-9]+
_EOF
done
%endif

# install LibreOfficeKit
install -m 0755 -d %{buildroot}%{_libdir}/girepository-1.0
install -m 0644 -p LOKDocView-%{girapiversion}.typelib %{buildroot}%{_libdir}/girepository-1.0/LOKDocView-%{girapiversion}.typelib
install -m 0755 -d %{buildroot}%{_libdir}/gir-1.0
install -m 0644 -p LOKDocView-%{girapiversion}.gir %{buildroot}%{_libdir}/gir-1.0/LOKDocView-%{girapiversion}.gir
mv %{buildroot}%{baseinstdir}/program/liblibreofficekitgtk.so %{buildroot}%{_libdir}
popd

# install LibreOfficeKit headers
install -m 0755 -d %{buildroot}%{_includedir}/LibreOfficeKit
install -m 0644 -p include/LibreOfficeKit/* %{buildroot}%{_includedir}/LibreOfficeKit

rm -rf %{buildroot}%{baseinstdir}/readmes
rm -rf %{buildroot}%{baseinstdir}/licenses
rm -rf %{buildroot}%{baseinstdir}/share/theme_definitions

# to-do, remove this in libreoffice 4.4 when --without-ppds is gone, it'll do the right thing on its own then
install -m 0755 -d %{buildroot}%{baseinstdir}/share/psprint/driver
install -m 0644 -p vcl/unx/generic/printer/configuration/ppds/SGENPRT.PS %{buildroot}%{baseinstdir}/share/psprint/driver/SGENPRT.PS

# rhbz#452385 to auto have postgres in classpath if subsequently installed
sed -i -e "s#URE_MORE_JAVA_CLASSPATH_URLS.*#& file:///usr/share/java/postgresql-jdbc.jar#" %{buildroot}%{baseinstdir}/program/fundamentalrc

# move glade catalog to system glade dir
install -m 0755 -d %{buildroot}%{_datadir}/glade/catalogs
mv %{buildroot}%{baseinstdir}/share/glade/libreoffice-catalog.xml %{buildroot}%{_datadir}/glade/catalogs
install -m 0755 -d %{buildroot}%{_datadir}/glade3/catalogs
ln -sr %{buildroot}%{_datadir}/glade/catalogs/libreoffice-catalog.xml %{buildroot}%{_datadir}/glade3/catalogs

# rhbz#1049543 install appdata
install -m 0755 -d %{buildroot}%{_datadir}/metainfo
install -m 0644 -p sysui/desktop/appstream-appdata/*.appdata.xml %{buildroot}%{_datadir}/metainfo

# rhbz#1215800 install symbolic icons
install -m 0755 -d %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE42} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE43} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE44} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE45} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE46} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE47} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -m 0644 -p %{SOURCE48} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps

%if 0%{?flatpak}
# Duplicate icons/*/*/apps/libreoffice-* as
# icons/*/*/apps/org.libreoffice.LibreOffice.* (so they end up "with both their
# original libreoffice-* name as well as the org.libreoffice name needed by
# Flatpak, which fixes the window icons", see <https://github.com/flathub/
# org.libreoffice.LibreOffice/commit/945f6caad87658b1df1e8918bd5f64939058ab7f>
# "clean up desktop integration"):
for i in %{buildroot}%{_datadir}/icons/*/*/apps/libreoffice-*; do
    cp -a "$i" \
     "$(dirname "$i")"/org.libreoffice.LibreOffice."${i##*/apps/libreoffice-}"
done
%endif

# install man pages
install -m 0755 -d %{buildroot}%{_mandir}/man1
install -m 0644 -p sysui/desktop/man/*.1 %{buildroot}%{_mandir}/man1
for app in oobase oocalc oodraw ooffice ooimpress oomath ooviewdoc oowriter openoffice.org soffice; do
    echo '.so man1/libreoffice.1' > $app.1
    install -m 0644 -p $app.1 %{buildroot}%{_mandir}/man1
done

export DESTDIR=%{buildroot}
./solenv/bin/install-gdb-printers -a %{_datadir}/gdb/auto-load%{baseinstdir} -c -i %{baseinstdir} -p %{_datadir}/libreoffice/gdb

%if 0%{?fedora}
# Update the screenshot shown in the software center
#
# NOTE: It would be *awesome* if this file was pushed upstream.
#
# See http://people.freedesktop.org/~hughsient/appdata/#screenshots for more details.
#
appstream-util replace-screenshots %{buildroot}%{_datadir}/metainfo/libreoffice-writer.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-writer/a.png \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-writer/b.png 
appstream-util replace-screenshots %{buildroot}%{_datadir}/metainfo/libreoffice-calc.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-calc/a.png 
appstream-util replace-screenshots %{buildroot}%{_datadir}/metainfo/libreoffice-draw.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-draw/a.png 
appstream-util replace-screenshots %{buildroot}%{_datadir}/metainfo/libreoffice-impress.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-impress/a.png 
%endif
%if 0%{?flatpak}
# Assemble the libreoffice-*.appdata.xml files into a single
# org.libreoffice.LibreOffice.appdata.xml; first create the single file:
solenv/bin/assemble-flatpak-appdata-step1.sh \
 %{buildroot}%{_datadir}/metainfo/ 0
%if 0%{?fedora}
# ...then update the screenshots in the single file (see above):
appstream-util replace-screenshots \
 %{buildroot}%{_datadir}/metainfo/org.libreoffice.LibreOffice.appdata.xml \
 https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-writer/a.png \
 https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-writer/b.png \
 https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-calc/a.png \
 https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-draw/a.png \
 https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/libreoffice-impress/a.png
%endif
# ...then append the original files to the single file:
solenv/bin/assemble-flatpak-appdata-step2.sh \
 %{buildroot}%{_datadir}/metainfo/ %{buildroot}%{_datadir}/metainfo/
rm %{buildroot}%{_datadir}/metainfo/libreoffice-*.appdata.xml
%endif

# rhbz#1247399 - move stable API jars to noarch java location
install -m 0755 -d %{buildroot}%{_javadir}/%{name}
for jar in %{buildroot}%{baseinstdir}/program/classes/*.jar; do
    j=`basename $jar`
    case ${j%.jar} in
        juh|jurt|ridl|unoloader|unoil|officebean)
            mv $jar %{buildroot}%{_javadir}/%{name}
            ln -sr %{buildroot}%{_javadir}/%{name}/$j $jar
            ;;
    esac
done

%check
%ifnarch ppc64 aarch64 armv7hl
make unitcheck slowcheck
# we don't need this anymore
rm -f %{buildroot}%{baseinstdir}/program/classes/smoketest.jar
%endif

%files

%files filters

%files core
%dir %{baseinstdir}
%{baseinstdir}/CREDITS.fodt
%{baseinstdir}/LICENSE.html
%dir %{baseinstdir}/help
%{baseinstdir}/help/idxcaption.xsl
%{baseinstdir}/help/idxcontent.xsl
%{baseinstdir}/help/main_transform.xsl
%{baseinstdir}/presets
%dir %{baseinstdir}/program
%if 0%{?fedora}
%{baseinstdir}/program/core.abignore
%endif
%{baseinstdir}/program/libbasprovlo.so
%{baseinstdir}/program/libcairocanvaslo.so
%{baseinstdir}/program/libcanvasfactorylo.so
%dir %{baseinstdir}/program/classes
%{baseinstdir}/program/classes/commonwizards.jar
%{baseinstdir}/program/classes/form.jar
%{baseinstdir}/program/classes/query.jar
%{baseinstdir}/program/classes/report.jar
%{baseinstdir}/program/classes/ScriptFramework.jar
%{baseinstdir}/program/classes/ScriptProviderForJava.jar
%{baseinstdir}/program/classes/table.jar
%{baseinstdir}/program/classes/unoil.jar
%{baseinstdir}/program/classes/XMergeBridge.jar
%{baseinstdir}/program/classes/xmerge.jar
%{baseinstdir}/program/libcmdmaillo.so
%{baseinstdir}/program/libdeployment.so
%{baseinstdir}/program/libdeploymentgui.so
%{baseinstdir}/program/libdlgprovlo.so
%{baseinstdir}/program/libexpwraplo.so
%{baseinstdir}/program/flat_logo.svg
%{baseinstdir}/program/libfps_officelo.so
%{baseinstdir}/program/gdbtrace
%{baseinstdir}/program/gengal
%{baseinstdir}/program/gengal.bin
%{baseinstdir}/program/libi18nsearchlo.so
%{baseinstdir}/program/libldapbe2lo.so
%{baseinstdir}/program/libacclo.so
%{baseinstdir}/program/libanimcorelo.so
%{baseinstdir}/program/libavmedia*.so
%{baseinstdir}/program/libbasctllo.so
%{baseinstdir}/program/libbiblo.so
%{baseinstdir}/program/libcached1.so
%{baseinstdir}/program/libcanvastoolslo.so
%{baseinstdir}/program/libchart*lo.so
%{baseinstdir}/program/libclewlo.so
%{baseinstdir}/program/libcollator_data.so
%{baseinstdir}/program/libcppcanvaslo.so
%{baseinstdir}/program/libctllo.so
%{baseinstdir}/program/libcuilo.so
%{baseinstdir}/program/libdbalo.so
%{baseinstdir}/program/libdbahsqllo.so
%{baseinstdir}/program/libdbaselo.so
%{baseinstdir}/program/libdbaxmllo.so
#{baseinstdir}/program/libdbmmlo.so
%{baseinstdir}/program/libdbpool2.so
%{baseinstdir}/program/libdbtoolslo.so
%{baseinstdir}/program/libdbulo.so
%{baseinstdir}/program/libdeploymentmisclo.so
%{baseinstdir}/program/libdesktop_detectorlo.so
%{baseinstdir}/program/libdict_ja.so
%{baseinstdir}/program/libdict_zh.so
%{baseinstdir}/program/libdrawinglayerlo.so
%{baseinstdir}/program/libeditenglo.so
%{baseinstdir}/program/libembobj.so
%{baseinstdir}/program/libemboleobj.so
%{baseinstdir}/program/libemfiolo.so
%{baseinstdir}/program/libevoab*.so
%{baseinstdir}/program/libevtattlo.so
%{baseinstdir}/program/libgielo.so
%{baseinstdir}/program/libicglo.so
%{baseinstdir}/program/libindex_data.so
%{baseinstdir}/program/libfilelo.so
%{baseinstdir}/program/libfilterconfiglo.so
%{baseinstdir}/program/libflatlo.so
%{baseinstdir}/program/libfrmlo.so
%{baseinstdir}/program/libguesslanglo.so
%{baseinstdir}/program/libhelplinkerlo.so
%{baseinstdir}/program/libhyphenlo.so
%{baseinstdir}/program/libjdbclo.so
%{baseinstdir}/program/liblnglo.so
%{baseinstdir}/program/libloglo.so
%{baseinstdir}/program/liblocaledata_en.so
%{baseinstdir}/program/liblocaledata_es.so
%{baseinstdir}/program/liblocaledata_euro.so
%{baseinstdir}/program/liblocaledata_others.so
%{baseinstdir}/program/libmcnttype.so
%{baseinstdir}/program/libmorklo.so
%{baseinstdir}/program/libmozbootstraplo.so
%{baseinstdir}/program/libmsfilterlo.so
%{baseinstdir}/program/libmtfrendererlo.so
%{baseinstdir}/program/libmysql_jdbclo.so
%{baseinstdir}/program/libmysqlclo.so
%{baseinstdir}/program/libodbclo.so
%{baseinstdir}/program/liboglcanvaslo.so
%{baseinstdir}/program/liboffacclo.so
%{baseinstdir}/program/libooxlo.so
%{baseinstdir}/program/libopencllo.so
%{baseinstdir}/program/libpcrlo.so
%{baseinstdir}/program/libpdffilterlo.so
%{baseinstdir}/program/libprotocolhandlerlo.so
%{baseinstdir}/program/libsaxlo.so
%{baseinstdir}/program/libscnlo.so
%{baseinstdir}/program/libscriptframe.so
%{baseinstdir}/program/libsdlo.so
%{baseinstdir}/program/libsdfiltlo.so
%{baseinstdir}/program/libsdbc2.so
%{baseinstdir}/program/libsdbtlo.so
%{baseinstdir}/program/libsddlo.so
%{baseinstdir}/program/libsduilo.so
%{baseinstdir}/program/libspelllo.so
%{baseinstdir}/program/libsrtrs1.so
%{baseinstdir}/program/libstoragefdlo.so
%{baseinstdir}/program/libsvgiolo.so
%{baseinstdir}/program/libsvxlo.so
%{baseinstdir}/program/libsvxcorelo.so
%{baseinstdir}/program/libswdlo.so
%{baseinstdir}/program/libswlo.so
%{baseinstdir}/program/libtextconv_dict.so
%{baseinstdir}/program/libtextconversiondlgslo.so
%{baseinstdir}/program/libtextfdlo.so
%{baseinstdir}/program/libodfflatxmllo.so
# TODO: shouldn't it have lo suffix?
%{baseinstdir}/program/libucbhelper.so
%{baseinstdir}/program/libucpchelp1.so
%{baseinstdir}/program/libucpdav1.so
%{baseinstdir}/program/libucpftp1.so
%{baseinstdir}/program/libucphier1.so
%{baseinstdir}/program/libucppkg1.so
%{baseinstdir}/program/libunordflo.so
%{baseinstdir}/program/libunopkgapp.so
%{baseinstdir}/program/libunoxmllo.so
%{baseinstdir}/program/libuuilo.so
%{baseinstdir}/program/libvbahelperlo.so
%{baseinstdir}/program/libxmlfalo.so
%{baseinstdir}/program/libxmlfdlo.so
%{baseinstdir}/program/libxoflo.so
%{baseinstdir}/program/libxsec_xmlsec.so
%{baseinstdir}/program/libxsltdlglo.so
%{baseinstdir}/program/libxsltfilterlo.so
%{baseinstdir}/program/libxstor.so
# TODO how useful this is in Fedora?
%{baseinstdir}/program/liblosessioninstalllo.so
%{baseinstdir}/program/libmigrationoo2lo.so
%{baseinstdir}/program/libmigrationoo3lo.so
%{baseinstdir}/program/libmsformslo.so
%{baseinstdir}/program/opencl
%dir %{baseinstdir}/program/opengl
%{baseinstdir}/program/opengl/*.glsl
%{baseinstdir}/program/types/offapi.rdb
%{baseinstdir}/program/libpasswordcontainerlo.so
%{baseinstdir}/program/pagein-common
%if %{with langpacks}
%dir %{baseinstdir}/program/resource
%endif
%{baseinstdir}/program/senddoc
%dir %{baseinstdir}/program/services
%{baseinstdir}/program/services/services.rdb
%{baseinstdir}/program/libsimplecanvaslo.so
%{baseinstdir}/program/libslideshowlo.so
%{baseinstdir}/program/libsmlo.so
%{baseinstdir}/program/libsmdlo.so
%{baseinstdir}/program/libsofficeapp.so
%{baseinstdir}/program/libstringresourcelo.so
%{baseinstdir}/program/libsysshlo.so
%{baseinstdir}/program/libucpcmis1lo.so
%{baseinstdir}/program/libucpexpand1lo.so
%{baseinstdir}/program/libucpextlo.so
%{baseinstdir}/program/libucpimagelo.so
%{baseinstdir}/program/libucptdoc1lo.so
%{baseinstdir}/program/lounorc
%{baseinstdir}/program/libupdatefeedlo.so
%{baseinstdir}/program/uri-encode
%{baseinstdir}/program/libvbaeventslo.so
%{baseinstdir}/program/libvclcanvaslo.so
%{baseinstdir}/program/versionrc
%dir %{baseinstdir}/share
%dir %{baseinstdir}/share/classification
%{baseinstdir}/share/classification/example*.xml
%dir %{baseinstdir}/share/fonts
%dir %{baseinstdir}/share/fonts/truetype
%{baseinstdir}/share/fonts/truetype/fc_local.conf
%dir %{baseinstdir}/share/Scripts
%{baseinstdir}/share/Scripts/java
%dir %{baseinstdir}/share/autotext
%dir %{_datadir}/autocorr
%{baseinstdir}/share/autocorr
%{baseinstdir}/share/basic
%dir %{baseinstdir}/share/config
%{baseinstdir}/share/config/images_breeze.zip
%{baseinstdir}/share/config/images_breeze_dark.zip
%{baseinstdir}/share/config/images_breeze_dark_svg.zip
%{baseinstdir}/share/config/images_colibre.zip
%{baseinstdir}/share/config/images_elementary.zip
%{baseinstdir}/share/config/images_helpimg.zip
%{baseinstdir}/share/config/images_karasa_jaga.zip
%{baseinstdir}/share/config/images_karasa_jaga_svg.zip
%{baseinstdir}/share/config/images_sifr.zip
%{baseinstdir}/share/config/images_sifr_dark.zip
%{baseinstdir}/share/config/images_sifr_dark_svg.zip
%{baseinstdir}/share/config/images_sifr_svg.zip
%{baseinstdir}/share/config/images_tango.zip
%{baseinstdir}/share/config/images_breeze_svg.zip
%{baseinstdir}/share/config/images_colibre_svg.zip
%{baseinstdir}/share/config/images_elementary_svg.zip
%dir %{baseinstdir}/share/tipoftheday
%{baseinstdir}/share/tipoftheday/*.png
%dir %{baseinstdir}/share/config/soffice.cfg
%{baseinstdir}/share/config/soffice.cfg/modules
%{baseinstdir}/share/config/soffice.cfg/*/ui
%dir %{baseinstdir}/share/emojiconfig
%{baseinstdir}/share/emojiconfig/emoji.json
%{baseinstdir}/share/palette
%{baseinstdir}/share/config/webcast
%{baseinstdir}/share/config/wizard
%dir %{baseinstdir}/share/dtd
%{baseinstdir}/share/dtd/officedocument
%{baseinstdir}/share/gallery
%dir %{baseinstdir}/share/labels
%{baseinstdir}/share/labels/labels.xml
%dir %{baseinstdir}/share/psprint
%config %{baseinstdir}/share/psprint/psprint.conf
%{baseinstdir}/share/psprint/driver
%dir %{baseinstdir}/share/registry
%{baseinstdir}/share/registry/draw.xcd
%{baseinstdir}/share/registry/gnome.xcd
%{baseinstdir}/share/registry/lingucomponent.xcd
%{baseinstdir}/share/registry/main.xcd
%{baseinstdir}/share/registry/math.xcd
%{baseinstdir}/share/registry/oo-ad-ldap.xcd.sample
%{baseinstdir}/share/registry/oo-ldap.xcd.sample
%dir %{baseinstdir}/share/registry/res
%dir %{baseinstdir}/share/template
%dir %{baseinstdir}/share/template/common
%{baseinstdir}/share/template/common/internal
%{baseinstdir}/share/template/common/officorr
%{baseinstdir}/share/template/common/offimisc
%{baseinstdir}/share/template/common/personal
%{baseinstdir}/share/template/common/presnt
%{baseinstdir}/share/template/common/styles
%{baseinstdir}/share/template/common/wizard
%{baseinstdir}/share/template/wizard
%dir %{baseinstdir}/share/wordbook
%{baseinstdir}/share/wordbook/en-GB.dic
%{baseinstdir}/share/wordbook/en-US.dic
%{baseinstdir}/share/wordbook/technical.dic
%{baseinstdir}/program/liblnthlo.so
%{_bindir}/unopkg
%{_mandir}/man1/unopkg.1*
%{baseinstdir}/program/libxmlsecurity.so
%{baseinstdir}/program/libconfigmgrlo.so
%{baseinstdir}/program/libdesktopbe1lo.so
%{baseinstdir}/program/libfsstoragelo.so
%{baseinstdir}/program/libi18npoollo.so
%{baseinstdir}/program/libbasegfxlo.so
# TODO: shouldn't it have lo suffix?
%{baseinstdir}/program/libcomphelper.so
%{baseinstdir}/program/libfwelo.so
%{baseinstdir}/program/libfwilo.so
%{baseinstdir}/program/libfwklo.so
%{baseinstdir}/program/libfwllo.so
%{baseinstdir}/program/libfwmlo.so
# TODO: shouldn't it have lo suffix?
%{baseinstdir}/program/libi18nutil.so
%{baseinstdir}/program/libpackage2.so
%{baseinstdir}/program/libsblo.so
%{baseinstdir}/program/libsfxlo.so
%{baseinstdir}/program/libsotlo.so
%{baseinstdir}/program/libspllo.so
%{baseinstdir}/program/libsvllo.so
%{baseinstdir}/program/libsvtlo.so
%{baseinstdir}/program/libtklo.so
%{baseinstdir}/program/libtllo.so
%{baseinstdir}/program/libucb1.so
%{baseinstdir}/program/libucpfile1.so
%{baseinstdir}/program/libutllo.so
%{baseinstdir}/program/libvcllo.so
%{baseinstdir}/program/libwriterperfectlo.so
%{baseinstdir}/program/libxmlscriptlo.so
%{baseinstdir}/program/libxolo.so
%{baseinstdir}/program/liblocalebe1lo.so
%{baseinstdir}/program/libucpgio1lo.so
%{baseinstdir}/program/types/oovbaapi.rdb
#share unopkg
%dir %{baseinstdir}/share/extensions
%{baseinstdir}/share/extensions/package.txt
%{baseinstdir}/program/unopkg
%{baseinstdir}/program/unopkg.bin
%{baseinstdir}/program/bootstraprc
%{baseinstdir}/program/fundamentalrc
%{baseinstdir}/program/setuprc
%{baseinstdir}/program/intro.png
%{baseinstdir}/program/intro-highres.png
%{baseinstdir}/program/opencltest
%{baseinstdir}/program/soffice
%{baseinstdir}/program/soffice.bin
%{baseinstdir}/program/sofficerc
%{baseinstdir}/program/unoinfo
%{baseinstdir}/program/oosplash
%{baseinstdir}/program/shell/
%dir %{baseinstdir}/share/filter
%{baseinstdir}/share/filter/oox-drawingml-adj-names
%{baseinstdir}/share/filter/oox-drawingml-cs-presets
%{baseinstdir}/share/filter/vml-shape-types
%{baseinstdir}/share/xdg/
%{baseinstdir}/program/redirectrc
%if 0%{?flatpak}
%{_datadir}/metainfo/org.libreoffice.LibreOffice.appdata.xml
%{_datadir}/applications/org.libreoffice.LibreOffice.desktop
%else
%{_datadir}/applications/libreoffice-startcenter.desktop
%endif
#launchers
%{_bindir}/libreoffice
%{_bindir}/openoffice.org
%{_bindir}/soffice
%{_bindir}/ooffice
%{_bindir}/ooviewdoc
%{_mandir}/man1/libreoffice.1*
%{_mandir}/man1/openoffice.org.1*
%{_mandir}/man1/soffice.1*
%{_mandir}/man1/ooffice.1*
%{_mandir}/man1/ooviewdoc.1*

%files base
%{baseinstdir}/program/classes/hsqldb.jar
%{baseinstdir}/program/classes/reportbuilder.jar
%{baseinstdir}/program/classes/reportbuilderwizard.jar
%{baseinstdir}/program/classes/sdbc_hsqldb.jar
%{baseinstdir}/program/access2base.py
%if 0%{?fedora}
%{baseinstdir}/program/base.abignore
%endif
%{baseinstdir}/program/libabplo.so
%{baseinstdir}/program/libdbplo.so
%{baseinstdir}/program/libhsqldb.so
%{baseinstdir}/program/librptlo.so
%{baseinstdir}/program/librptuilo.so
%{baseinstdir}/program/librptxmllo.so
%{baseinstdir}/share/registry/base.xcd
%{baseinstdir}/share/registry/reportbuilder.xcd
%{baseinstdir}/program/sbase
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.base.desktop
%else
%{_datadir}/metainfo/libreoffice-base.appdata.xml
%{_datadir}/applications/libreoffice-base.desktop
%endif
%{_bindir}/oobase
%{_mandir}/man1/oobase.1*

%if 0%{?fedora}
%files bsh
%{baseinstdir}/program/classes/ScriptProviderForBeanShell.jar
%{baseinstdir}/program/services/scriptproviderforbeanshell.rdb
%{baseinstdir}/share/Scripts/beanshell

%files rhino
%{baseinstdir}/program/classes/js.jar
%{baseinstdir}/program/classes/ScriptProviderForJavaScript.jar
%{baseinstdir}/program/services/scriptproviderforjavascript.rdb
%{baseinstdir}/share/Scripts/javascript
%endif

%files wiki-publisher
%docdir %{baseinstdir}/share/extensions/wiki-publisher/license
%{baseinstdir}/share/extensions/wiki-publisher

%files nlpsolver
%docdir %{baseinstdir}/share/extensions/nlpsolver/help
%{baseinstdir}/share/extensions/nlpsolver

%files officebean
%{baseinstdir}/program/classes/officebean.jar
%if 0%{?fedora}
%{baseinstdir}/program/officebean.abignore
%endif
%{baseinstdir}/program/libofficebean.so

%files officebean-common
%{_javadir}/%{name}/officebean.jar

%files ogltrans
%if 0%{?fedora}
%{baseinstdir}/program/ogltrans.abignore
%endif
%{baseinstdir}/program/libOGLTranslo.so
%{baseinstdir}/program/opengl/basicFragmentShader.glsl
%{baseinstdir}/program/opengl/basicVertexShader.glsl
%{baseinstdir}/program/opengl/dissolveFragmentShader.glsl
%{baseinstdir}/program/opengl/fadeBlackFragmentShader.glsl
%{baseinstdir}/program/opengl/fadeFragmentShader.glsl
%{baseinstdir}/program/opengl/glitterFragmentShader.glsl
%{baseinstdir}/program/opengl/glitterVertexShader.glsl
%{baseinstdir}/program/opengl/honeycombFragmentShader.glsl
%{baseinstdir}/program/opengl/honeycombGeometryShader.glsl
%{baseinstdir}/program/opengl/honeycombVertexShader.glsl
%{baseinstdir}/program/opengl/rippleFragmentShader.glsl
%{baseinstdir}/program/opengl/reflectionFragmentShader.glsl
%{baseinstdir}/program/opengl/reflectionVertexShader.glsl
%{baseinstdir}/program/opengl/staticFragmentShader.glsl
%{baseinstdir}/program/opengl/vortexFragmentShader.glsl
%{baseinstdir}/program/opengl/vortexGeometryShader.glsl
%{baseinstdir}/program/opengl/vortexVertexShader.glsl
%{baseinstdir}/share/config/soffice.cfg/simpress/transitions-ogl.xml
%{baseinstdir}/share/registry/ogltrans.xcd

%files pdfimport
%if 0%{?fedora}
%{baseinstdir}/program/pdfimport.abignore
%endif
%{baseinstdir}/program/libpdfimportlo.so
%{baseinstdir}/program/xpdfimport
%{baseinstdir}/share/registry/pdfimport.xcd
%dir %{baseinstdir}/share/xpdfimport
%{baseinstdir}/share/xpdfimport/xpdfimport_err.pdf

%_font_pkg -n %{fontname} opens___.ttf
%doc instdir/LICENSE

%files calc
%if 0%{?fedora}
%{baseinstdir}/program/calc.abignore
%endif
%{baseinstdir}/program/libanalysislo.so
%{baseinstdir}/program/libcalclo.so
%{baseinstdir}/program/libdatelo.so
%{baseinstdir}/program/libforlo.so
%{baseinstdir}/program/libforuilo.so
%{baseinstdir}/program/libnumbertextlo.so
%{baseinstdir}/program/libpricinglo.so
%{baseinstdir}/program/libsclo.so
%{baseinstdir}/program/libscdlo.so
%{baseinstdir}/program/libscfiltlo.so
%{baseinstdir}/program/libscuilo.so
%{baseinstdir}/program/libsolverlo.so
%{baseinstdir}/program/libwpftcalclo.so
%{baseinstdir}/program/libvbaobjlo.so
%{baseinstdir}/share/calc/styles.xml
%{baseinstdir}/share/registry/calc.xcd
%{baseinstdir}/program/pagein-calc
%{baseinstdir}/program/scalc
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.calc.desktop
%else
%{_datadir}/metainfo/libreoffice-calc.appdata.xml
%{_datadir}/applications/libreoffice-calc.desktop
%endif
%{_bindir}/oocalc
%{_mandir}/man1/oocalc.1*

%files draw
%{baseinstdir}/program/pagein-draw
%{baseinstdir}/program/sdraw
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.draw.desktop
%else
%{_datadir}/metainfo/libreoffice-draw.appdata.xml
%{_datadir}/applications/libreoffice-draw.desktop
%endif
%{_bindir}/oodraw
%{_mandir}/man1/oodraw.1*

%files emailmerge
%{baseinstdir}/program/mailmerge.py*
%{baseinstdir}/program/msgbox.py*

%files writer
%if 0%{?fedora}
%{baseinstdir}/program/writer.abignore
%endif
%{baseinstdir}/program/libhwplo.so
%{baseinstdir}/program/liblwpftlo.so
%{baseinstdir}/program/libmswordlo.so
%{baseinstdir}/program/libswuilo.so
%{baseinstdir}/program/libt602filterlo.so
%{baseinstdir}/program/libwpftwriterlo.so
%{baseinstdir}/program/libwriterfilterlo.so
%{baseinstdir}/program/libwriterlo.so
%{baseinstdir}/program/libvbaswobjlo.so
%{baseinstdir}/share/registry/writer.xcd
%{baseinstdir}/program/pagein-writer
%{baseinstdir}/program/swriter
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.writer.desktop
%else
%{_datadir}/metainfo/libreoffice-writer.appdata.xml
%{_datadir}/applications/libreoffice-writer.desktop
%endif
%{_bindir}/oowriter
%{_mandir}/man1/oowriter.1*

%files impress
%if 0%{?fedora}
%{baseinstdir}/program/impress.abignore
%endif
%{baseinstdir}/program/libPresentationMinimizerlo.so
%{baseinstdir}/program/libPresenterScreenlo.so
%{baseinstdir}/program/libwpftimpresslo.so
%dir %{baseinstdir}/share/config/soffice.cfg/simpress
%{baseinstdir}/share/config/soffice.cfg/simpress/effects.xml
%{baseinstdir}/share/config/soffice.cfg/simpress/layoutlist.xml
%{baseinstdir}/share/config/soffice.cfg/simpress/objectlist.xml
%{baseinstdir}/share/config/soffice.cfg/simpress/transitions.xml
%{baseinstdir}/share/registry/impress.xcd
%{baseinstdir}/program/pagein-impress
%{baseinstdir}/program/simpress
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.impress.desktop
%else
%{_datadir}/metainfo/libreoffice-impress.appdata.xml
%{_datadir}/applications/libreoffice-impress.desktop
%endif
%{_bindir}/ooimpress
%{_mandir}/man1/ooimpress.1*

%files math
%{baseinstdir}/program/smath
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.math.desktop
%else
%{_datadir}/applications/libreoffice-math.desktop
%endif
%{_bindir}/oomath
%{_mandir}/man1/oomath.1*

%files graphicfilter
%if 0%{?fedora}
%{baseinstdir}/program/graphicfilter.abignore
%endif
%{baseinstdir}/program/libflashlo.so
%{baseinstdir}/program/libgraphicfilterlo.so
%{baseinstdir}/program/libsvgfilterlo.so
%{baseinstdir}/program/libwpftdrawlo.so
%{baseinstdir}/share/registry/graphicfilter.xcd

%files xsltfilter
%{baseinstdir}/share/xslt
%{baseinstdir}/share/registry/xsltfilter.xcd
%if 0%{?flatpak}
%{_datadir}/applications/org.libreoffice.LibreOffice.xsltfilter.desktop
%else
%{_datadir}/applications/libreoffice-xsltfilter.desktop
%endif

%files postgresql
%if 0%{?fedora}
%{baseinstdir}/program/postgresql.abignore
%endif
%{baseinstdir}/program/libpostgresql-sdbclo.so
%{baseinstdir}/program/libpostgresql-sdbc-impllo.so
%{baseinstdir}/program/postgresql-sdbc.ini
%{baseinstdir}/program/services/postgresql-sdbc.rdb
%{baseinstdir}/share/registry/postgresql.xcd

%files ure
%{baseinstdir}/program/classes/java_uno.jar
%{baseinstdir}/program/classes/juh.jar
%{baseinstdir}/program/classes/jurt.jar
%{baseinstdir}/program/classes/ridl.jar
%{baseinstdir}/program/classes/unoloader.jar
%{baseinstdir}/program/javaldx
%{baseinstdir}/program/javavendors.xml
%{baseinstdir}/program/jvmfwk3rc
%{baseinstdir}/program/JREProperties.class
%if 0%{?fedora}
%{baseinstdir}/program/ure.abignore
%endif
%{baseinstdir}/program/libaffine_uno_uno.so
%{baseinstdir}/program/libbinaryurplo.so
%{baseinstdir}/program/libbootstraplo.so
%{baseinstdir}/program/libgcc3_uno.so
%{baseinstdir}/program/libi18nlangtag.so
%{baseinstdir}/program/libintrospectionlo.so
%{baseinstdir}/program/libinvocadaptlo.so
%{baseinstdir}/program/libinvocationlo.so
%{baseinstdir}/program/libiolo.so
%{baseinstdir}/program/libjava_uno.so
%{baseinstdir}/program/libjavaloaderlo.so
%{baseinstdir}/program/libjavavmlo.so
%{baseinstdir}/program/libjpipe.so
%{baseinstdir}/program/libjuh.so
%{baseinstdir}/program/libjuhx.so
%{baseinstdir}/program/libjvmaccesslo.so
%{baseinstdir}/program/libjvmfwklo.so
%{baseinstdir}/program/liblog_uno_uno.so
%{baseinstdir}/program/libnamingservicelo.so
%{baseinstdir}/program/libproxyfaclo.so
%{baseinstdir}/program/libreflectionlo.so
%{baseinstdir}/program/libreglo.so
%{baseinstdir}/program/libsal_textenclo.so
%{baseinstdir}/program/libstocserviceslo.so
%{baseinstdir}/program/libstorelo.so
%{baseinstdir}/program/libuno_cppu.so.3
%{baseinstdir}/program/libuno_cppuhelpergcc3.so.3
%{baseinstdir}/program/libuno_purpenvhelpergcc3.so.3
%{baseinstdir}/program/libuno_sal.so.3
%{baseinstdir}/program/libuno_salhelpergcc3.so.3
%{baseinstdir}/program/libunoidllo.so
%{baseinstdir}/program/libunsafe_uno_uno.so
%{baseinstdir}/program/libuuresolverlo.so
%{baseinstdir}/program/libxmlreaderlo.so
%{baseinstdir}/program/regmerge
%{baseinstdir}/program/regview
%{baseinstdir}/program/services.rdb
%{baseinstdir}/program/types.rdb
%{baseinstdir}/program/uno
%{baseinstdir}/program/uno.bin
%{baseinstdir}/program/unorc

%files ure-common
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/juh.jar
%{_javadir}/%{name}/jurt.jar
%{_javadir}/%{name}/ridl.jar
%{_javadir}/%{name}/unoloader.jar
%license instdir/LICENSE

%files sdk
%{sdkinstdir}/
%exclude %{sdkinstdir}/docs/
%exclude %{sdkinstdir}/examples/

%files sdk-doc
%docdir %{sdkinstdir}/docs
%license instdir/LICENSE
%{sdkinstdir}/docs/
%{sdkinstdir}/examples/

%files pyuno
%if 0%{?fedora}
%{baseinstdir}/program/pyuno.abignore
%endif
%{baseinstdir}/program/libpyuno.so
%{baseinstdir}/program/pythonloader.py*
%{baseinstdir}/program/libpythonloaderlo.so
%{baseinstdir}/program/pythonloader.unorc
%{baseinstdir}/program/pythonscript.py*
%{baseinstdir}/program/pyuno.so
%{baseinstdir}/program/services/pyuno.rdb
%{baseinstdir}/program/services/scriptproviderforpython.rdb
%{baseinstdir}/program/wizards
%{baseinstdir}/share/Scripts/python
%exclude %{baseinstdir}/share/Scripts/python/LibreLogo
%{libo_python_sitearch}/uno.py*
%{libo_python_sitearch}/unohelper.py*
%{libo_python_sitearch}/officehelper.py*
%if ! 0%{?flatpak}
%{libo_python_sitearch}/__pycache__/uno.cpython-*
%{libo_python_sitearch}/__pycache__/unohelper.cpython-*
%{libo_python_sitearch}/__pycache__/officehelper.cpython-*
%endif
%{baseinstdir}/share/registry/pyuno.xcd

%files librelogo
%{baseinstdir}/share/registry/librelogo.xcd
%{baseinstdir}/share/Scripts/python/LibreLogo

%files glade
%{baseinstdir}/program/ui-previewer
%{_datadir}/glade
%{_datadir}/glade3

%files data
%{_datadir}/icons/hicolor/*/*/libreoffice*
%{_datadir}/icons/locolor/*/*/libreoffice*
%if 0%{?flatpak}
%{_datadir}/icons/hicolor/*/*/org.libreoffice.LibreOffice.*
%{_datadir}/icons/locolor/*/*/org.libreoffice.LibreOffice.*
%endif
%{_datadir}/mime-info/libreoffice.*
%{_datadir}/mime/packages/libreoffice.xml
# TODO: rename -data to -core-common?
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/unoil.jar
%dir %{datadir}
%doc instdir/CREDITS.fodt
%doc instdir/LICENSE.html
%doc instdir/LICENSE
%doc instdir/NOTICE
%license instdir/LICENSE

%post data
for theme in hicolor locolor; do
    touch --no-create %{_datadir}/icons/$theme &>/dev/null || :
done

%postun data
if [ $1 -eq 0 ] ; then
    for theme in hicolor locolor; do
        touch --no-create %{_datadir}/icons/$theme &>/dev/null || :
        gtk-update-icon-cache -q %{_datadir}/icons/$theme &>/dev/null || :
    done
fi

%posttrans data
for theme in hicolor locolor; do
    gtk-update-icon-cache -q %{_datadir}/icons/$theme &>/dev/null || :
done

%files x11
%if 0%{?fedora}
%{baseinstdir}/program/x11.abignore
%endif
%{baseinstdir}/program/libvclplug_genlo.so

%files gtk3
%if 0%{?fedora}
%{baseinstdir}/program/gtk3.abignore
%endif
%{baseinstdir}/program/libvclplug_gtk3lo.so

%if 0%{?fedora}

%files kde5
%if 0%{?fedora}
%{baseinstdir}/program/kde5.abignore
%endif
%{baseinstdir}/program/libkf5be1lo.so
%{baseinstdir}/program/libvclplug_kf5lo.so
%{baseinstdir}/program/libvclplug_qt5lo.so

%files kf5
%{baseinstdir}/program/libvclplug_gtk3_kde5lo.so
%{baseinstdir}/program/lo_kde5filepicker

%endif

%files -n libreofficekit
%{baseinstdir}/share/libreofficekit
%{_libdir}/girepository-1.0/LOKDocView-%{girapiversion}.typelib
%if 0%{?fedora}
%{baseinstdir}/program/libreofficekit.abignore
%endif
%{_libdir}/liblibreofficekitgtk.so

%files -n libreofficekit-devel
%{_libdir}/gir-1.0/LOKDocView-%{girapiversion}.gir
%{_includedir}/LibreOfficeKit

%changelog
* Tue Mar 11 2025 Eike Rathke <erack@redhat.com> - 1:6.4.7.2-19
- Fix CVE-2025-1080 Filter out more unwanted command URIs

* Thu Aug 15 2024 Eike Rathke <erack@redhat.com> - 1:6.4.7.2-18
- Fix CVE-2024-6472 remove ability to trust not validated macro signatures in
  high security

* Fri Jun 07 2024 Eike Rathke <erack@redhat.com> - 1:6.4.7.2-17
- Fix CVE-2024-3044 add notify for script use

* Mon Mar 11 2024 Eike Rathke <erack@redhat.com> - 1:6.4.7.2-16
- Fix CVE-2023-6185 escape url passed to gstreamer
- Fix CVE-2023-6186 check link target protocols

* Mon Jun 19 2023 Stephan Bergmann <sbergman@redhat.com> - 1:6.4.7.2-15
- Resolves: rhbz#2210191 CVE-2023-0950 Array Index UnderFlow in Calc Formula
  Parsing
- Resolves: rhbz#2210195 CVE-2023-2255 libreoffice: Remote documents loaded
  without prompt via IFrame
- Resolves: rhbz#2208509 CVE-2023-1183 libreoffice: Arbitrary File Write

* Wed Apr 12 2023 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-14
- Resolves: rhbz#2182390 CVE-2022-38745 Empty entry in Java class path

* Mon Nov 21 2022 Stephan Bergmann <sbergman@redhat.com> - 1:6.4.7.2-13
- Resolves: rhbz#2031681 Failure saving to smb share

* Fri Oct 14 2022 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-12
- Resolves: rhbz#2118928 CVE-2022-26305 Untrusted Macros
- Resolves: rhbz#2118924 CVE-2022-26307 Weak Master Keys
- Resolves: rhbz#2118920 CVE-2022-26306 Static Initialization Vector
- Resolves: rhbz#2134702 CVE-2022-3140 Macro URL arbitrary script execution

* Mon Mar 07 2022 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-11
- Resolves: rhbz#2060559 CVE-2021-25636

* Mon Feb 07 2022 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-10
- Related: rhbz#2029810  bump n-v-r

* Mon Jan 31 2022 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-9
- Related: rhbz#2029810 set NoDisplay=true for .desktop on s390x/aarch64
- Related: rhbz#2029810 don't Require any vclplug for s390x/aarch64

* Tue Dec 07 2021 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-8
- Resolves: rhbz#2029810 enable make check on s390x

* Fri Oct 15 2021 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-7
- Resolves: rhbz#2013858 CVE-2021-25633
- Resolves: rhbz#2014215 CVE-2021-25634
- Resolves: rhbz#2014209 CVE-2021-25635

* Mon Sep 06 2021 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-6
- Resolves: rhbz#1980800 allow convert to csv to write each sheet to
  separate file
- Resolves: rhbz#1992695 two style tags where there should be one

* Wed Feb 03 2021 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-5
- Resolves: rhbz#1924619 bad insertion of emoji

* Mon Nov 09 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-4
- Resolves: rhbz#1889801 rebuild for poppler

* Thu Oct 29 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-3
- Related: rhbz#1874234 fix upgrade dependency problems

* Wed Oct 28 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-2
- Related: rhbz#1874234 hang in check

* Wed Oct 21 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.4.7.2-1
- Resolves: rhbz#1874234 latest stable release

* Wed Jul 08 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.6.2-3
- Obsoletes any libreoffice-gtk2-debuginfo along with libreoffice-gtk2

* Tue Jun 02 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.6.2-2
- Resolves: rhbz#1841907 always produce utf-8 from gettext

* Tue Apr 28 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.6.2-1
- rhbz#1796893 latest stable release

* Tue Apr 14 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-7
- rhbz#1796893 don't show error dialog on G_IO_ERROR_FAILED_HANDLED

* Wed Apr 01 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-6
- rhbz#1819798 Start Center crash after pressing Help button before
  using any topevel module

* Fri Mar 27 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-5
- rhbz#1796893 spreadsheetml2ooo.xsl was not well formed xml
- rhbz#1796893 fix impress print dialog range

* Mon Mar 23 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-4
- rhbz#1796893 fix help->licence info->license

* Fri Mar 20 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-3
- rhbz#1796893 disable tip of the day by default

* Thu Mar 19 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-2
- rhbz#1796893 improve langpack requires

* Fri Mar 06 2020 Caolán McNamara <caolanm@redhat.com> - 1:6.3.5.2-1
- rhbz#1796893 latest stable release

* Mon Oct 14 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-20
- Resolves: rhbz#1743958 CVE-2019-9849, etc.
- Resolves: rhbz#1648281 Junk character gets added when some emojis are inserted

* Mon Aug 19 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-19
- Related: rhbz#1691287 escape backslashes etc in username

* Tue Aug 13 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-18
- Resolves: rhbz#1691287 improve prompt for auth-info-required

* Fri Jun 28 2019 Marek Kasik <mkasik@redhat.com> - 1:6.0.6.1-17
- Rebuild due to soname bump in poppler-0.66.0-21
- Resolves: #1715842

* Tue Jun 04 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-16
- Resolves: rhbz#1715109 add 'All files' to the graphic filter list

* Fri Apr 26 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-15
- Resolves: rhbz#1703375 disable bsh and rhino for rhel

* Fri Mar 29 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-14
- Resolves: rhbz#1691287 prompt for auth-info-required

* Fri Feb 08 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-13
- Related: rhbz#1672004 fix serbian/swedish autocorr rpm upgrade

* Sun Feb 03 2019 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-12
- Resolves: rhbz#1672004 CVE-2018-16858

* Thu Nov 15 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-11
- Resolves: rhbz#1649251 impress webpreview doesn't work without graphicfilter
- Resolves: rhbz#1648949 fix docx missing date forms

* Thu Nov 08 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-10
- Resolves: rhbz#1647507 try user password for both pdf modes

* Wed Oct 10 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-9
- Resolves: rhbz#1637848 enable weak-deps Supplements for langpacks

* Tue Sep 18 2018 Tomas Orsava <torsava@redhat.com> - 1:6.0.6.1-8
- Resolves: rhbz#1619153 Require the Python interpreter directly instead of
  relying on the package name

* Fri Aug 31 2018 Stephan Bergmann <sbergman@redhat.com> - 1:6.0.6.1-7
- Resolves: rhbz#1618703 Use OpenSSL instead of internal cipher functionality

* Fri Aug 10 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-6.3
- Resolves: rhbz#1614376 FTBFS

* Thu Jul 26 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-6
- Related: rhbz#1602589 fix/silence more covscan warnings

* Fri Jul 20 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-5
- implement export of underline in outlined font for simple case

* Wed Jul 18 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-4
- Resolves: rhbz#1602589 fix covscan issues

* Tue Jul 17 2018 Eike Rathke <erack@redhat.com> - 1:6.0.6.1-3
- Upgrade to ICU 61.1
- Upgrade to ICU 62.1

* Tue Jul 17 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-2
- Resolves: rhbz#1601882 fails to build with --nocheck

* Tue Jul 17 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.6.1-1
- latest 6.0 release

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:6.0.5.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Pete Walter <pwalter@fedoraproject.org> - 1:6.0.5.2-2
- Rebuild for ICU 62

* Fri Jun 22 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.5.2-1
- latest 6.0 release
- fix for ICU 61
- fix for Python 3.7

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1:6.0.4.2-5
- Rebuilt for Python 3.7

* Tue Jun 05 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.4.2-4
- Resolves: rhbz#1581028 endless font widget update

* Tue Jun 05 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.4.2-3
- use weak deps for fedora only

* Mon May 28 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.4.2-2
- Resolves: rhbz#1582324 crash after merging writer table cells

* Fri May 25 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.4.2-1
- latest 6.0 release

* Wed May 9 2018 Stephan Bergmann <sbergman@redhat.com> - 1:6.0.3.2-10
- Fix a potential crash when using the dconf configuration backend

* Sat May 5 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-9
- tdf#117413 char doubling in calc under X

* Fri May 4 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-8
- rhbz#1575000 CVE-2018-10583 allow embedded links to smb resources
  to be blocked

* Thu May 3 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-7
- rhbz#1573845 won't start without at least Langpack-en-US.xcd

* Mon Apr 30 2018 Pete Walter <pwalter@fedoraproject.org> - 1:6.0.3.2-6
- Rebuild for ICU 61.1

* Tue Apr 24 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-5
- Resolves: tdf#116951 rhbz#1569331 start is G_MAXINT

* Thu Apr 19 2018 Stephan Bergmann <sbergman@redhat.com> - 1:6.0.3.2-4
- Resolves: rhbz#1568579 LibreOffice --headless zombie process
- Related: rhbz#1569331 end should be in terms of unicode chars, not bytes

* Tue Apr 17 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-3
- Related: rhbz#1396729 use cairo_surface_create_similar

* Tue Apr 10 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-2
- finally drop bundled xmlsec1

* Thu Mar 29 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.2-1
- latest version

* Thu Mar 29 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.3.1-3
- Related: rhbz#1066844 drop libreofficekit requires

* Fri Mar 23 2018 Marek Kasik <mkasik@redhat.com> - 1:6.0.3.1-2
- Rebuild for poppler-0.63.0

* Thu Mar 22 2018 David Tardon <dtardon@redhat.com> - 1:6.0.3.1-1
- update to 6.0.3 rc1

* Fri Mar 16 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.2.1-3
- Resolves: rhbz#1392145 ensure titlebar close button matches 'outside' direction

* Fri Mar 16 2018 Stephan Bergmann <sbergman@redhat.com> - 1:6.0.2.1-2
- lib dir missing from libreoffice-sdk

* Fri Feb 23 2018 David Tardon <dtardon@redhat.com> - 1:6.0.2.1-1
- update to 6.0.2 rc1

* Wed Feb 14 2018 David Tardon <dtardon@redhat.com> - 1:6.0.1.1-2
- rebuild for poppler 0.62.0

* Fri Feb 09 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.1.1-1
- latest stable

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:6.0.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Feb 06 2018 Stephan Bergmann <sbergman@redhat.com> - 1:6.0.0.3-2-UNBUILT
- Resolves: rhbz#1541486 Base table dialog title shown in wrong language

* Sun Feb 04 2018 David Tardon <dtardon@redhat.com> - 1:6.0.0.3-1
- update to 6.0.0 rc3

* Wed Jan 31 2018 Michael Stahl <mstahl@fedoraproject.org> - 1:6.0.0.2-3
- add lots of .abignore files to restrict abipkgdiff to shared objects
  that actually have a stable ABI

* Tue Jan 30 2018 Björn Esser <besser82@fedoraproject.org> - 1:6.0.0.2-2
- Rebuilt for Boost 1.66.0

* Fri Jan 12 2018 David Tardon <dtardon@redhat.com> - 1:6.0.0.2-1
- update to 6.0.0 rc2

* Tue Jan 09 2018 Caolán McNamara <caolanm@redhat.com> - 1:6.0.0.1-3
- bump to Modify2 for app_id so install hint says 'LibreOffice wants to install'

* Thu Dec 21 2017 Caolán McNamara <caolanm@redhat.com> - 1:6.0.0.1-2
- request langpack for autodetected desired ui locale via packagekit

* Wed Dec 20 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.1-1
- update to 6.0.0 rc1

* Thu Dec 14 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.0-8.beta2
- update to 6.0.0 beta2

* Mon Dec 04 2017 Caolán McNamara <caolanm@redhat.com> - 1:6.0.0.0-7.beta1
- Rebuild for hunspell 1.6.2

* Thu Nov 30 2017 Pete Walter <pwalter@fedoraproject.org> - 1:6.0.0.0-6.beta1
- Rebuild for ICU 60.1

* Sat Nov 25 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.0-5.beta1
- update to 6.0.0 beta1

* Wed Nov 22 2017 Eike Rathke <erack@redhat.com> - 1:6.0.0.0-4.alpha1
- prepare for build with ICU 60.1

* Mon Nov 20 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.0-3.alpha1
- rebuild for liborcus 0.13.1

* Wed Nov 08 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.0-2.alpha1
- rebuild for poppler 0.61.0

* Thu Nov 02 2017 David Tardon <dtardon@redhat.com> - 1:6.0.0.0-1.alpha1
- update to 6.0.0 alpha1
- update location of appdata files
- use weak dependencies
- mark bundled packages

* Tue Oct 17 2017 David Tardon <dtardon@redhat.com> - 1:5.4.3.1-1
- update to 5.4.3 rc1

* Fri Oct 06 2017 David Tardon <dtardon@redhat.com> - 1:5.4.2.2-3
- rebuild for poppler 0.60.1

* Sun Oct 01 2017 Thierry Vignaud <tvignaud@redhat.com> - 1:5.4.2.2-2
- fix libreoffice wrapper

* Wed Sep 27 2017 David Tardon <dtardon@redhat.com> - 1:5.4.2.2-1
- update to 5.4.2 rc2

* Mon Sep 18 2017 David Tardon <dtardon@redhat.com> - 1:5.4.2.1-1
- update to 5.4.2 rc1

* Tue Sep 12 2017 David Tardon <dtardon@redhat.com> - 1:5.4.1.2-3
- Resolves: rhbz#1490318 do not use versioned Supplements

* Fri Sep 08 2017 David Tardon <dtardon@redhat.com> - 1:5.4.1.2-2
- rebuild for poppler 0.59.0

* Sun Aug 27 2017 David Tardon <dtardon@redhat.com> - 1:5.4.1.2-1
- update to 5.4.1 rc2

* Fri Aug 11 2017 Caolán McNamara <caolanm@redhat.com> - 1:5.4.0.3-5
- implement char highlighting ui for graphics styles

* Thu Aug 03 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.3-4
- rebuild for poppler 0.57.0

* Mon Jul 31 2017 Kalev Lember <klember@redhat.com> - 1:5.4.0.3-3
- Enable the s390x build again

* Mon Jul 31 2017 Kalev Lember <klember@redhat.com> - 1:5.4.0.3-2
- Temporarily disable the build on s390x

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:5.4.0.3-1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Kalev Lember <klember@redhat.com> - 1:5.4.0.2-2
- Rebuilt for Boost 1.64

* Fri Jul 07 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.2-1
- update to 5.4.0 rc2

* Fri Jun 23 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.1-1
- update to 5.4.0 rc1

* Wed Jun 07 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.0-3.beta2
- update to 5.4.0 beta2

* Sun May 21 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.0-2.beta1
- update to 5.4.0 beta1

* Tue May 02 2017 David Tardon <dtardon@redhat.com> - 1:5.4.0.0-1.alpha1
- update to 5.4.0 alpha1

* Wed Apr 19 2017 David Tardon <dtardon@redhat.com> - 1:5.3.3.1-1
- update to 5.3.3 rc1

* Wed Mar 29 2017 David Tardon <dtardon@redhat.com> - 1:5.3.2.2-1
- update to 5.3.2 rc2

* Tue Mar 28 2017 David Tardon <dtardon@redhat.com> - 1:5.3.2.1-3
- rebuild for poppler 0.53.0

* Mon Mar 27 2017 Caolán McNamara <caolanm@redhat.com> - 1:5.3.2.1-2
- Resolves: rhbz#1432468 disable opencl by default

* Sun Mar 19 2017 David Tardon <dtardon@redhat.com> - 1:5.3.2.1-1
- update to 5.3.2 rc1

* Mon Mar 13 2017 Caolán McNamara <caolanm@redhat.com> - 1:5.3.1.2-2
- Resolves: rhbz#1431189 add Indonesian langpack

* Thu Mar 09 2017 David Tardon <dtardon@redhat.com> - 1:5.3.1.2-1
- update to 5.3.1 rc2

* Thu Feb 23 2017 David Tardon <dtardon@redhat.com> - 1:5.3.1.1-1
- update to 5.3.1 rc1

* Tue Feb 07 2017 Björn Esser <besser82@fedoraproject.org> - 1:5.3.0.3-3
- Rebuilt for Boost 1.63

* Thu Feb 02 2017 Caolán McNamara <caolanm@redhat.com> - 1:5.3.0.3-2
- Resolves: rhbz#1409401 add depend on gtksink gstreamer1 element

* Fri Jan 27 2017 David Tardon <dtardon@redhat.com> - 1:5.3.0.3-1
- update to 5.3.0 rc3

* Wed Jan 18 2017 David Tardon <dtardon@redhat.com> - 1:5.3.0.2-1
- update to 5.3.0 rc2
- temp. disable building of help on ARM to fix build

* Tue Jan 10 2017 David Tardon <dtardon@redhat.com> - 1:5.3.0.1-1
- update to 5.3.0 rc1

* Tue Dec 27 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.3.0.0-8.beta1
- try arm build

* Thu Dec 22 2016 Miro Hrončok <mhroncok@redhat.com> - 1:5.3.0.0-7.beta2
- Rebuild for Python 3.6

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1:5.3.0.0-6.beta2
- Rebuild for Python 3.6

* Thu Dec 15 2016 David Tardon <dtardon@redhat.com> - 1:5.3.0.0-5.beta2
- update to 5.3.0 beta2

* Tue Dec 13 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.3.0.0-4.beta1
- rebuild for hunspell-1.5.4

* Wed Nov 23 2016 David Tardon <dtardon@redhat.com> - 1:5.3.0.0-3.beta1
- update to 5.3.0 beta1

* Tue Nov 08 2016 David Tardon <dtardon@redhat.com> - 1:5.3.0.0-2.alpha1
- allow abrt to work again

* Sat Oct 22 2016 David Tardon <dtardon@redhat.com> - 1:5.3.0.0-1.alpha1
- update to 5.3.0 alpha1

* Fri Oct 21 2016 Marek Kasik <mkasik@redhat.com> - 1:5.2.3.1-2
- Rebuild for poppler-0.48.0

* Sat Oct 15 2016 David Tardon <dtardon@redhat.com> - 1:5.2.3.1-1
- update to 5.2.3 rc1

* Fri Oct 07 2016 Stephan Bergmann <sbergman@redhat.com> - 1:5.2.2.2-3
- Resolves: rhbz#1382401 broken export of emojis to HTML

* Thu Sep 29 2016 David Tardon <dtardon@redhat.com> - 1:5.2.2.2-2
- rebuild for liborcus 0.12

* Wed Sep 21 2016 David Tardon <dtardon@redhat.com> - 1:5.2.2.2-1
- update to 5.2.2 rc2

* Wed Sep 21 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.2.2.1-5
- Related: rhbz#1362451 apply patch

* Tue Sep 20 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.2.2.1-4
- Related: rhbz#1362451 avoid recursive ownerchanged signal during ownerchange

* Mon Sep 19 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.2.2.1-3
- Related: rhbz#1373933 do less on style-updated
- Related: rhbz#1353069 don't clear XATTR_FILL from in use styles

* Fri Sep 16 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.2.2.1-2
- Resolves: rhbz#1373933 gtk 3.21 emits way too many "style-set" signals

* Wed Sep 14 2016 David Tardon <dtardon@redhat.com> - 1:5.2.2.1-1
- update to 5.2.2 rc1

* Tue Sep 13 2016 Stephan Bergmann <sbergman@redhat.com> - 1:5.2.1.2-3
- enable dconf support for Fleet Commander

* Mon Sep 05 2016 David Tardon <dtardon@redhat.com> - 1:5.2.1.2-2
- Resolves: rhbz#1247399 install public jars according to packaging guidelines
- Resolves: rhbz#1363874 install LibreOfficeKit headers

* Fri Aug 26 2016 David Tardon <dtardon@redhat.com> - 1:5.2.1.2-1
- update to 5.2.1 rc2

* Thu Aug 11 2016 David Tardon <dtardon@redhat.com> - 1:5.2.1.1-1
- update to 5.2.1 rc1

* Fri Jul 29 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.4-1
- update to 5.2.0 rc4

* Thu Jul 21 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.3-1
- update to 5.2.0 rc3

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:5.2.0.2-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Jul 18 2016 Marek Kasik <mkasik@redhat.com> - 1:5.2.0.2-3
- Rebuild for poppler-0.45.0

* Thu Jul 07 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.2-2
- remove obsolete wiki-publisher requires apache-commons-*

* Thu Jul 07 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.2-1
- update to 5.2.0 rc2
- Resolves: rhbz#1351292 fix switching of modes in Impress

* Tue Jun 28 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.1-2
- Resolves: rhbz#1341064 fix test on big endian systems

* Wed Jun 22 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.1-1
- update to 5.1.0 rc1
- Resolves: rhbz#1343752 wrong radiobutton and checkbutton behavior in
  "view" menu
- Resolves: rhbz#1349261 do not pull in all variants of english dicts

* Thu Jun 09 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-8.beta2
- update to 5.2.0 beta2

* Thu May 26 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-7.beta1
- update to 5.2.0 beta1

* Mon May 16 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-6.alpha1
- Resolves: rhbz#1327847 remove multilib conflicts in .desktop files

* Fri May 13 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-5.alpha1
- rebuild for mdds 1.2.0
- Resolves: rhbz#1325858 fix build on 64-bit secondary arches

* Tue May 10 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-4.alpha1
- Resolves: rhbz#1333899 recommended pkgs are omitted from default
  installation

* Tue May  3 2016 Marek Kasik <mkasik@redhat.com> - 1:5.2.0.0-3.alpha1
- Rebuild for poppler-0.43.0

* Mon May 02 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-2.alpha1
- Resolves: rhbz#1326602 leakage of removed background image set in master slide

* Fri Apr 22 2016 David Tardon <dtardon@redhat.com> - 1:5.2.0.0-1.alpha1
- update to 5.2.0 alpha1

* Thu Apr 21 2016 David Tardon <dtardon@redhat.com> - 1:5.1.3.1-1
- update to 5.1.3 rc1
- Resolves: tdf#91778 drawing the background over an active cursor

* Mon Apr 18 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.1.2.1-6
- rebuild for hunspell 1.4.0

* Fri Apr 15 2016 David Tardon <dtardon@redhat.com> - 1:5.1.2.1-5
- rebuild for ICU 57.1

* Thu Apr 07 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.1.2.1-4
- gtk3: fix combobox and listbox

* Wed Mar 30 2016 David Tardon <dtardon@redhat.com> - 1:5.1.2.1-3
- support both glade and glade3

* Mon Mar 21 2016 David Tardon <dtardon@redhat.com> - 1:5.1.2.1-2
- Resolves: rhbz#1319458 avoid rich deps in Requires

* Wed Mar 16 2016 David Tardon <dtardon@redhat.com> - 1:5.1.2.1-1
- update to 5.1.2 rc1
- split VCL plugins into subpackages
- rename libreoffice-kde to libreoffice-kde4
- only recommend fonts
- remove hard dependency on English spell checker and auto-correction
  rules
- disable quickstarter
- move icons and other system-integration stuff to a noarch subpackage
- disable browser plugin in preparation for its removal in 5.2

* Wed Mar 09 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.3-2
- update for liborcus 0.11.0

* Thu Mar 03 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.3-1
- update to 5.1.1 rc3

* Fri Feb 26 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.2-1
- update to 5.1.1 rc2

* Mon Feb 22 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.1-5
- Resolves: rhbz#1310527 add langpack deps

* Tue Feb 16 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.1.1.1-4
- video playback under wayland with gstreamer gtksink

* Mon Feb 15 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.1-3
- rebuild for openCOLLADA soname change

* Sun Feb 14 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.1-2
- switch to mdds 1.x

* Thu Feb 11 2016 David Tardon <dtardon@redhat.com> - 1:5.1.1.1-1
- update to 5.1.1 rc1
- Resolves: rhbz#1303007 add noarch Provides too

* Thu Feb 11 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.1.0.3-3
- rework gtk3 themeing to work with latest gtk

* Tue Feb 02 2016 Caolán McNamara <caolanm@redhat.com> - 1:5.1.0.3-2
- Resolves: rhbz#1303619 nothing provides java-devel(x86_64)

* Wed Jan 27 2016 David Tardon <dtardon@redhat.com> - 1:5.1.0.3-1
- update to 5.1.0 rc3
- Resolves: rhbz#1168757 Selecting multiple slides is not reflected in Print
  dialog

* Fri Jan 22 2016 Marek Kasik <mkasik@redhat.com> - 1:5.1.0.2-5
- Rebuild for poppler-0.40.0

* Mon Jan 18 2016 Jonathan Wakely <jwakely@redhat.com> - 1:5.1.0.2-4
- Rebuilt for Boost 1.60

* Sat Jan 16 2016 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1:5.1.0.2-3
- Remove arch-specific dependency for font subpackage as it is noarch

* Thu Jan 14 2016 Adam Jackson <ajax@redhat.com> - 1:5.1.0.2-2
- Rebuild for glew 1.13

* Thu Jan 14 2016 David Tardon <dtardon@redhat.com> - 1:5.1.0.2-1
- update to 5.1.0 rc2

* Thu Dec 17 2015 Bastien Nocera <bnocera@redhat.com> 1:5.1.0.1-2
- Add GLSL files missing from the package
- Split up inclusion of latin Serbian files to avoid duplicate listing

* Wed Dec 16 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.1-1
- update to 5.1.0 rc1

* Mon Dec 14 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-11.beta2
- backport more upstream fixes for libreofficekit
- fix unit test on i686

* Wed Dec 09 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-10.beta2
- backport upstream fixes for libreofficekit

* Fri Dec 04 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-9.beta2
- update to 5.1.0 beta2

* Thu Dec 03 2015 Caolán McNamara <caolanm@redhat.com> - 1:5.1.0.0-8.beta1
- enable and bundle libreofficekit introspection

* Thu Nov 26 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-7.beta1
- update to 5.1.0 beta1

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:5.1.0.0-6.alpha1
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Nov 05 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-5.alpha1
- Related: rhbz#1276061 build failure on ppc64

* Tue Nov 03 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-4.alpha1
- Resolves: rhbz#1276061 build failure on ppc64

* Wed Oct 28 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-3.alpha1
- rebuild for ICU 56.1

* Tue Oct 27 2015 Eike Rathke <erack@redhat.com> - 1:5.1.0.0-2.alpha1
- prepare to enable build with ICU 56

* Mon Oct 19 2015 David Tardon <dtardon@redhat.com> - 1:5.1.0.0-1.alpha1
- update to 5.1.0 alpha1

* Mon Oct 12 2015 David Tardon <dtardon@redhat.com> - 1:5.0.3.1-1
- update to 5.0.3 rc1

* Thu Oct 08 2015 Caolán McNamara <caolanm@redhat.com> - 1:5.0.2.2-4
- Resolves: rhbz#1269593 declare support for vnd.libreoffice.cmis:// URLs

* Wed Sep 30 2015 Caolán McNamara <caolanm@redhat.com> - 1:5.0.2.2-3
- implement save slide background for impress

* Mon Sep 28 2015 Caolán McNamara <caolanm@redhat.com> - 1:5.0.2.2-2
- Resolves: tdf#93461 captions laid out behind images

* Thu Sep 17 2015 David Tardon <dtardon@redhat.com> - 1:5.0.2.2-1
- update to 5.0.2 rc2

* Sat Sep 05 2015 David Tardon <dtardon@redhat.com> - 1:5.0.2.1-1
- update to 5.0.2 rc1

* Sat Aug 22 2015 David Tardon <dtardon@redhat.com> - 1:5.0.1.2-1
- update to 5.0.1 rc2

* Tue Aug 11 2015 David Tardon <dtardon@redhat.com> - 1:5.0.1.1-1
- update to 5.0.1 rc1

* Wed Aug 05 2015 Jonathan Wakely <jwakely@redhat.com> 5.0.0.5-2
- Rebuilt for Boost 1.58

* Mon Aug 03 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.5-1
- update to 5.0.0 rc5

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:5.0.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Sat Jul 25 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.4-1
- update to 5.0.0 rc4

* Fri Jul 24 2015 Adam Williamson <awilliam@redhat.com> - 1:5.0.0.3-3
- rebuild for Boost 1.58 (for real this time)

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.3-2
- rebuild for Boost 1.58

* Fri Jul 10 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.3-1
- update to 5.0.0 rc3

* Sun Jun 28 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.2-1
- update to 5.0.0 rc2

* Sun Jun 21 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.1-1
- update to 5.0.0 rc1

* Fri Jun 19 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-8.beta3
- Resolves: rhbz#1233420 crash on auto-fill

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:5.0.0.0-7.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 10 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-6.beta3
- update to 5.0.0 beta3

* Tue Jun 09 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-5.beta2
- update to 5.0.0 beta2

* Mon Jun 08 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-4.beta1
- rebuild for poppler 0.33

* Wed May 20 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-3.beta1
- update to 5.0.0 beta1

* Sat May 16 2015 Kalev Lember <kalevlember@gmail.com> - 1:5.0.0.0-2.alpha1
- Resolves: rhbz#1215800 install symbolic icons

* Sun Apr 19 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-1.alpha1
- update to 5.0.0 alpha1

* Tue Apr 14 2015 Stephan Bergmann <sbergman@redhat.com> - 1:4.4.2.2-3
- Resolves: rhbz#1197614 crash when updating extension
- Resolves: rhbz#1134285 redundant user/password request for WebDAV access

* Mon Mar 30 2015 Richard Hughes <rhughes@redhat.com> - 1:4.4.2.2-2
- Use better AppData screenshots

* Thu Mar 26 2015 David Tardon <dtardon@redhat.com> - 1:4.4.2.2-1
- update to 4.4.2 rc2

* Thu Mar 12 2015 David Tardon <dtardon@redhat.com> - 1:4.4.2.1-1
- update to 4.2.2 rc1

* Mon Feb 23 2015 David Tardon <dtardon@redhat.com> - 1:4.4.1.2-1
- update to 4.4.1 rc2

* Tue Feb 10 2015 David Tardon <dtardon@redhat.com> - 1:4.4.1.1-1
- update to 4.4.1 rc1

* Thu Jan 29 2015 David Tardon <dtardon@redhat.com> - 1:4.4.0.3-5
- fix build on s390

* Wed Jan 28 2015 Petr Machata <pmachata@redhat.com> - 1:4.4.0.3-4
- Rebuild for boost 1.57.0

* Wed Jan 28 2015 Petr Machata <pmachata@redhat.com> - 1:4.4.0.3-3
- Rebuild for boost 1.57.0

* Fri Jan 23 2015 Stephan Bergmann <sbergman@redhat.com> - 1:4.4.0.3-2
- Related: rhbz#1185307 get search for Hamcrest unstuck

* Fri Jan 23 2015 David Tardon <dtardon@redhat.com> - 1:4.4.0.3-1
- update to 4.4.0 rc3

* Fri Jan 23 2015 Marek Kasik <mkasik@redhat.com> - 1:4.4.0.2-4
- Rebuild (poppler-0.30.0)

* Thu Jan 22 2015 Stephan Bergmann <sbergman@redhat.com> - 1:4.4.0.2-3
- Resolves: rhbz#1184582 crash in grammar checking thread

* Mon Jan 19 2015 David Tardon <dtardon@redhat.com> - 1:4.4.0.2-2
- Resolves: rhbz#1180114 writerfilter: don't crash on w:customXmlDelRangeStart
  etc.
- Resolves: rhbz#1175027 fix life cycle of SwConnectionDisposedListener_Impl

* Fri Jan 09 2015 David Tardon <dtardon@redhat.com> - 1:4.4.0.2-1
- update to 4.4.0 rc2

* Wed Jan 07 2015 Caolán McNamara <caolanm@redhat.com> - 1:4.4.0.1-2
- Resolves: rhbz#1177547 system autocorr files not detected

* Sun Dec 21 2014 David Tardon <dtardon@redhat.com> - 1:4.4.0.1-1
- update to 4.4.0 rc1

* Fri Dec 12 2014 David Tardon <dtardon@redhat.com> - 1:4.4.0.0-6.beta2
- Resolves: rhbz#1116534 crash when pasting over a formula

* Sat Dec 06 2014 David Tardon <dtardon@redhat.com> - 1:4.4.0.0-5.beta2
- update to 4.4.0 beta2
- move officehelper.py to pyuno package so it can be imported from python

* Tue Dec 02 2014 David Tardon <dtardon@redhat.com> - 1:4.4.0.0-4.beta1
- add Provides: libreoffice-headless; packages are depending on it

* Thu Nov 27 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.4.0.0-3.beta1
- Resolves: rhbz#1165444 abrt crash with NULL pView

* Thu Nov 27 2014 Marek Kasik <mkasik@redhat.com> - 1:4.4.0.0-2.beta1
- Rebuild (poppler-0.28.1)

* Sat Nov 22 2014 David Tardon <dtardon@redhat.com> - 1:4.4.0.0-1.beta1
- update to 4.4.0 beta1

* Fri Nov 21 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.4.1-6
- Resolves: fdo#86466 Wrong background color shown in impress table

* Thu Nov 20 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.4.1-5
- Resolves: rhbz#1164551 we want to ensure that a libjvm.so is available
  but we have no firm interest in which one that is

* Wed Nov 19 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.4.1-4
- Resolves: rhbz#1165740 arbitrarily backport some rtf crash fixes

* Mon Nov 17 2014 Michael Stahl <mstahl@redhat.com>- 1:4.3.4.1-3
- set VCL.WM.ShouldSwitchWorkspace to false to avoid virtual desktop switching

* Thu Nov 13 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.4.1-2
- fix impress table layout cache wrt wrong table selection border

* Tue Nov 11 2014 David Tardon <dtardon@redhat.com> - 1:4.3.4.1-1
- update to 4.3.4 rc1

* Tue Nov 11 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.3.2-6
- strip hard coded numbering off outline master previews

* Mon Nov 10 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.3.2-5
- Resolves: rhbz#1161238 sync PRESOBJ_OUTLINE para depth on load

* Thu Nov 06 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.3.2-4
- Resolves: fdo#60712 Inherits cell styles in inserting rows/columns
- implement toggling off removeable master elements with delete
- Resolves: fdo#78151 change underlying style on toggling bullets on/off in master view

* Thu Nov 06 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.3.2-3
- Resolves: fdo#76581 copy-and-paste -> slideshow crash in presenter console

* Wed Nov 05 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.3.2-2
- Resolves: fdo#37559 revert adding extra dummy polygons

* Tue Oct 28 2014 David Tardon <dtardon@redhat.com> - 1:4.3.3.2-1
- update to 4.3.3 rc2

* Sun Oct 19 2014 David Tardon <dtardon@redhat.com> - 1:4.3.3.1-2
- enable support for 3-D models

* Thu Oct 09 2014 David Tardon <dtardon@redhat.com> - 1:4.3.3.1-1
- update to 4.3.3 rc1

* Wed Oct 08 2014 Stephan Bergmann <sbergman@redhat.com> - 1:4.3.2.2-5
- Resolves: rhbz#1054952 bad access of smb URLs on KDE

* Tue Sep 23 2014 Richard Hughes <richard@hughsie.com> - 1:4.3.2.2-4
- move appdata files to desktop files, where the belong

* Tue Sep 23 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.2.2-3
- Resolves: rhbz#1054952 cannot access smb URLs on KDE

* Tue Sep 23 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.2.2-2
- make brochure printing of impress/draw work out of the box
- Resolves: rhbz#1133863 fix looping layout

* Mon Sep 22 2014 David Tardon <dtardon@redhat.com> - 1:4.3.2.2-1
- update to 4.3.2 rc2

* Wed Sep 17 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.2.1-3
- make n-up printing of impress notes work out of the box

* Wed Sep 17 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.2.1-2
- Resolves: fdo#80911 don't swap notes page width height

* Fri Sep 12 2014 David Tardon <dtardon@redhat.com> - 1:4.3.2.1-1
- update to 4.3.2 rc1

* Wed Sep 10 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.2-5
- create a master document template type

* Tue Sep 09 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.2-4
- Resolves: fdo#82496 Change picture option with right click in writer

* Fri Sep 05 2014 David Tardon <dtardon@redhat.com> - 1:4.3.1.2-3
- build for aarch64

* Fri Aug 29 2014 Stephan Bergmann <sbergman@redhat.com> - 1:4.3.1.2-2
- Resolves: rhbz#1098693 AArch64 port

* Wed Aug 27 2014 David Tardon <dtardon@redhat.com> - 1:4.3.1.2-1
- update to 4.3.1 rc2

* Tue Aug 26 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.1-8
- Related: rhbz#1131425 ure only needs jre-headless

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 1:4.3.1.1-7
- rebuild for ICU 53.1

* Fri Aug 22 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.1-6
- Resolves: rhbz#1131425 move libjawt-using office bean into a subpackage
- Resolves: rhbz#1125588 port LibreOffice to ppc64le

* Tue Aug 19 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.1-5
- Resolves: rhbz#1131425 try java-headless instead of java

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:4.3.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Aug 16 2014 Rex Dieter <rdieter@fedoraproject.org> 1:4.3.1.1-3
- update mime scriptlets

* Fri Aug 15 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.1.1-2
- Related: rhbz#1130264 crash in media playback on s390x

* Sun Aug 10 2014 David Tardon <dtardon@redhat.com> - 1:4.3.1.1-1
- update to 4.3.1 rc1

* Mon Jul 28 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.4-1
- update to 4.3.0 rc4

* Fri Jul 25 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.3-4
- Resolves: rhbz#1121254 crash when using font selector after adding new font

* Fri Jul 25 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.3.0.3-3
- Resolves: rhbz#1122868 landscape printing is broken

* Thu Jul 24 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.3-2
- avoid image loss in Impress after auto-save

* Wed Jul 16 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.1-1
- update to 4.3.0 rc3

* Tue Jul 08 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.2-2
- avoid problems detecting HTML files with xls extension

* Wed Jul 02 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.2-1
- update to 4.3.0 rc2

* Tue Jun 17 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.1-1
- update to 4.3.0 rc1

* Mon Jun 09 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-9.beta2
- Resolves: rhbz#1105376 FlatODF import/export does not work unless
  libreoffice-xsltfilter is installed

* Wed Jun 04 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-8.beta2
- update to 4.3.0 beta2

* Thu May 29 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-7.beta1
- fix some fallout from the import libs rebase

* Wed May 28 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-6.beta1
- switch to librevenge-based import libs

* Tue May 27 2014 Kalev Lember <kalevlember@gmail.com> - 1:4.3.0.0-5.beta1
- Rebuild for boost 1.55.0

* Mon May 26 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-4.beta1
- unblock build on ARM

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 1:4.3.0.0-3.beta1
- Rebuild for boost 1.55.0

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-2.beta1
- rebuild for boost 1.55.0

* Wed May 21 2014 David Tardon <dtardon@redhat.com> - 1:4.3.0.0-1.beta1
- update to 4.3.0 beta1

* Fri May 16 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-14
- render smart-art with a vector format so it can be scaled nicely
- fix leak on pasting metafiles into office
- fix leak on pasting draw items into office
- fix another leak on scaling metric items

* Thu May 15 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.2-13
- fix SDK doc generation with doxygen 1.8.7

* Wed May 14 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.2-12
- rebuild for new poppler

* Mon May 12 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-11
- Resolves: rhbz#1096747 format->page crash on html doc

* Mon May 12 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.2-10
- Resolves: fdo#78119 bad july (červenec) month name support in czech
  localization

* Mon May 12 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-9
- Resolves: rhbz#1096486 avoid access to nonexisting parent
- Resolves: rhbz#1096295 hard to distinguish slides in slide pane

* Fri May 09 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.2-8
- Resolves: rhbz#1071604 Draw depends on files from libreoffice-impress, crashes
  without them

* Fri May 09 2014 Eike Rathke <erack@redhat.com> - 1:4.2.4.2-7
- Resolves: fdo#77509 memory corruption / crash in Consolidate

* Thu May 08 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-6
- center current slide after changing zoom
- add a status bar icon to fit slide to window
- Related: fdo#50697 reset the cache timeout on GetGraphic

* Thu May 08 2014 Stephan Bergmann <sbergman@redhat.com> - 1:4.2.4.2-5
- Resolves: rhbz#1092589 Thoroughly check whether JRE is still present

* Tue May 06 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-4
- clip over-long comments

* Thu May 01 2014 Eike Rathke <erack@redhat.com> - 1:4.2.4.2-3
- Resolves: fdo#78294 default null-date for document import is 1899-12-30

* Thu May 01 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.2-2
- better scaling of notes-using pages

* Wed Apr 30 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.2-1
- update to 4.2.4 rc2

* Fri Apr 25 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-7
- Related: rhbz#1032774 disable autoexit when switching monitors

* Thu Apr 24 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-6
- Resolves: fdo#37130 use 10pt Default style font for comments
- Resolves: fdo#60040 crash after undoing master page
- vertically center printout when including comments

* Wed Apr 23 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-5
- add a 'format all comments' feature

* Tue Apr 22 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-4
- Resolves: rhbz#1089377 crash on loading a specific rtf

* Tue Apr 22 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-3
- sometimes tables in impress don't resize when adding rows
- Resolves: fdo#71423 crash while editing Impress tables

* Fri Apr 18 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.4.1-2
- every 2nd print job is incorrectly flagged as failed
- Related: rhbz#1088625 PresenterPaintManager seen as NULL

* Thu Apr 17 2014 David Tardon <dtardon@redhat.com> - 1:4.2.4.1-1
- update to 4.2.4 rc1

* Wed Apr 16 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.3-6
- install man pages
- Resolves: rhbz#1086714 overlarge pixmap

* Wed Apr 16 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.3.3-5
- Resolves: fdo#36815 enable printing WYSIWYG sidewindow comments

* Sat Apr 12 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.3-4
- drop filtering of provides again

* Sat Apr 12 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.3.3-3
- Related: rhbz#1081176 don't jump to cursor pos when we don't want to

* Fri Apr 11 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.3.3-2
- Resolves: rhbz#1081176 don't jump to cursor pos when we don't want to
- Related: rhbz#1085916 kde startup woes

* Sat Apr 05 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.3-1
- update to 4.2.3 rc3

* Tue Apr 01 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.3.2-3
- Related: rhbz#1075951 abrt crash in MSWordExportBase

* Mon Mar 31 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.2-2
- Resolves: rhbz#1080196 mdds/multi_type_vector_itr.hpp update_node():
  soffice.bin killed by SIGSEGV

* Wed Mar 26 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.2-1
- update to 4.2.3 rc2

* Tue Mar 25 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.3.1-2
- Resolves: rhbz#1077780 crash on loading a specific docx

* Mon Mar 17 2014 David Tardon <dtardon@redhat.com> - 1:4.2.3.1-1
- update to 4.2.3 rc1

* Fri Mar 14 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.2.1-7
- Related: rhbz#1076264 intermittent a11y crash in calc

* Mon Mar 10 2014 Michael Stahl <mstahl@redhat.com> - 1:4.2.2.1-6
- Resolves: rhbz#988516: DOCX import: fix context stack when importing header
- Resolves: rhbz#1072553: Fix deselection problems of template view
- Resolves: rhbz#1072607: fix crash in SvxRuler::MouseMove()
- Resolves: rhbz#1043551: sw: avoid division-by-0 in Text Grid painting code
- RTF import: import field parameters
- RTF import: fix spurious page breaks at doc end

* Tue Mar 04 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.2.1-5
- Related: rhbz#1065807 wizards should find the right wizards subdir
  of Template_internal, who knew this stuff was so fragile

* Mon Mar 03 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.2.1-4
- Related: rhbz#1065807 wizards should look in Template_internal

* Fri Feb 28 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.2.1-3
- Resolves: rhbz#1007697 Update on a Window deletes itself

* Fri Feb 28 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.2.1-2
- Related: rhbz#1065807 don't throw with no "Templates" dir under KDE

* Thu Feb 27 2014 David Tardon <dtardon@redhat.com> - 1:4.2.2.1-1
- update to 4.2.2 rc1

* Thu Feb 27 2014 Stephan Bergmann <sbergman@redhat.com> - 1:4.2.1.1-4
- Resolves: fdo#75540 spadmin does not start

* Thu Feb 27 2014 David Tardon <dtardon@redhat.com> - 1:4.2.1.1-3
- Resolves: rhbz#1057977 do not crash when fonts are updated

* Tue Feb 25 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.1.1-2
- Resolves: rhbz#1065807 search XDG defined "Templates" dir

* Thu Feb 13 2014 David Tardon <dtardon@redhat.com> - 1:4.2.1.1-1
- update to 4.2.1 rc1

* Thu Feb 13 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.4-4
- rebuild for new ICU

* Thu Feb 06 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.4-3
- Resolves: rhbz#1017379 libreoffice impress imports animated motion paths
  incorrectly from powerpoint
- Resolves: fdo#33852 Custom animation (Motionpath Left) isn't being
  imported correctly from .ppt

* Thu Jan 30 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.4-2
- split LibreLogo into a separate subpackage
- create a metapackage depending on all subpackages containing filters,
  for use of packages like unoconv

* Tue Jan 28 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.4-1
- update to 4.2.0 rc4

* Fri Jan 24 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.3-3
- enable EOT support
- fix PPC build

* Thu Jan 23 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.3-2
- stop showing math and startcenter in menu (again)

* Wed Jan 22 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.3-1
- update to 4.2.0 rc3

* Mon Jan 13 2014 Caolán McNamara <caolanm@redhat.com> - 1:4.2.0.2-2
- Related: rhbz#1047871 conditional formatting doesn't fit on screen

* Thu Jan 09 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.2-1
- update to 4.2.0 rc2
- Resolves: rhbz#1049543 Include AppData files in packages

* Tue Jan 07 2014 David Tardon <dtardon@redhat.com> - 1:4.2.0.1-1
- 4.2.0 rc1

* Wed Dec 11 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.2.0.0-3.beta2
- Resolves: rhbz#1040291 Change language name from "Oriya" to "Odia"

* Wed Dec 04 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.2.0.0-2.beta2
- update to 4.2.0 beta2
- Related: rhbz#1032774 bodge around reported NULL
- Resolves: rhbz#1035092 no shortcut key for Italian 'Tools' menu
- Resolves: rhbz#912529 Kerkis SmallCaps shown instead of Kerkis Regular
- Resolves: rhbz#1038189 refresh printer list when print dialog launched
- openssl no longer required to build

* Thu Nov 21 2013 David Tardon <dtardon@redhat.com> - 1:4.2.0.0-1.beta1
- switch to 4.2.0

* Wed Nov 20 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.1.3.2-5
- Resolves: rhbz#1031989 Accept --pt in addition to deprecated -pt
- Related: rhbz#1014990 valgrind reports uninitialized variables

* Sun Nov 03 2013 David Tardon <dtardon@redhat.com> - 1:4.1.3.2-4
- adapt for libmwaw 0.2

* Thu Oct 31 2013 David Tardon <dtardon@redhat.com> - 1:4.1.3.2-3
- Resolves: fdo#56209 reviving FilterFormulaParser

* Thu Oct 31 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.1.3.2-2
- Resolves: fdo#67725 unoidl::AggregatingCursor must wrap modules for aggregation
- Resolves: rhbz#1021915 force menubar menus to be up/down only
- Resolves: rhbz#1025201 Incorrect rendering of Devanagari short i

* Wed Oct 23 2013 David Tardon <dtardon@redhat.com> - 1:4.1.3.2-1
- 4.1.3 rc2
- Resolves: rhbz#1022094 libreoffice-4.1.3.1-1 was built without
  langpacks

* Mon Oct 21 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.3.1-2
- Resolves: rhbz#1020712 wrong default CTL font shown in editengine
- Resolves: rhbz#919070 display -1 means span all screens


* Wed Oct 16 2013 David Tardon <dtardon@redhat.com> - 1:4.1.3.1-1
- 4.1.3 rc1

* Mon Oct 07 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.2.3-4
- Resolves: rhbz#1001768: fix various a11y deadlocks and crashes
- Resolves: rhbz#1016022 fix cut from impress and paste to writer
- Resolves: rhbz#1003179 fix AUTOFMT related crashes in Writer Undo

* Mon Oct 07 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.2.3-3
- Resolves: rhbz#1015281 crash on clicking custom animation
- Resolves: rhbz#996162 crash with no bullet font

* Wed Oct 02 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.2.3-2
- Resolves: rhbz#1013480 crash in EditLineList::operator[]
- Resolves: rhbz#1014010 crash on start up
- Resolves: rhbz#1013844 encrypted OOo 1.0 files don't reopen

* Mon Sep 30 2013 David Tardon <dtardon@redhat.com> - 1:4.1.2.3-1
- 4.1.2 rc3

* Fri Sep 20 2013 David Tardon <dtardon@redhat.com> - 1:4.1.2.2-1
- 4.1.2 rc2

* Tue Sep 17 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.2.1-3
- add select sheet menu to calc prev/next area
- Resolves: rhbz#988104 crash on certain pptx

* Thu Sep 12 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.2.1-2
- Resolves: rhbz#1006850 crash in SwCommentRuler

* Thu Sep 05 2013 David Tardon <dtardon@redhat.com> - 1:4.1.2.1-1
- 4.1.2 rc1

* Tue Sep 03 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.1.2-3
- Resolves: rhbz#993963 NULL m_pWindow on firefox close plugin window

* Fri Aug 23 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.1.1.2-2
- Resolves: rhbz#1000150, Do not call exit upon XIOError

* Thu Aug 22 2013 David Tardon <dtardon@redhat.com> - 1:4.1.1.2-1
- 4.1.1 rc2
- Related: rhbz#895690 Always try to do a mount when opening a file via GIO
- Resolves: rhbz#998136 wrong index to gWidgetData
- Resolves: rhbz#998046 store last size/position of the base windows

* Mon Aug 19 2013 Marek Kasik <mkasik@redhat.com> - 1:4.1.1.1-2
- Rebuild (poppler-0.24.0)

* Fri Aug 09 2013 David Tardon <dtardon@redhat.com> - 1:4.1.1.1-1
- 4.1.1 rc1

* Fri Aug 09 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.4-6
- Resolves: fdo#67743 user autocorr file not written

* Tue Jul 30 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.1.0.4-5
- Resolves: rhbz#989246 Honor user's JavaDriverClass override in mysql driver
- Resolves: fdo#67045 fix several nasty screen selection issues

* Tue Jul 30 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.4-4
- Resolves: rhbz#989686 Fix crash with stripping whitespace from toc entries

* Mon Jul 29 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.4-3
- make libwpd-based filters work correctly with newest libwpd

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 1:4.1.0.4-2
- Rebuild for boost 1.54.0

* Wed Jul 24 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.4-1
- 4.1.0 rc4

* Mon Jul 22 2013 Eike Rathke <erack@redhat.com> - 1:4.1.0.3-2
- force rebuild with icu-50.1.2-7

* Thu Jul 18 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.3-1
- 4.1.0 rc3
- Resolves: fdo#48835 GNOME3 app menu

* Thu Jul 18 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.2-5
- silence scary gcc warning
- fdo#66924 switching to master view is broken

* Tue Jul 16 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.2-4
- bump release

* Fri Jul 12 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.2-3
- Resolves: rhbz#983809 libreoffice-base misses deps on needed java packages

* Thu Jul 11 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.2-2
- Resolves: rhbz#980387 Exporting a odg to jpg or tiff generates error

* Thu Jul 04 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.2-1
- 4.1.0 rc2

* Mon Jul 01 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.1-8
- Resolves: rhbz#979758 crash on Diagrammen in LibreOffice help page

* Thu Jun 27 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.1-7
- bump revision

* Mon Jun 24 2013 Marek Kasik <mkasik@redhat.com> - 1:4.1.0.1-6
- Rebuild (poppler-0.22.5)

* Mon Jun 24 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.1-5
- fix build on big endian archs

* Mon Jun 24 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.1-4
- put glade catalog into an extra packgae

* Sun Jun 23 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.1-3
- Resolves: rhbz#976304 gallery elements may not insert

* Wed Jun 19 2013 Dennis Gilmore <dennis@ausil.us> - 1:4.1.0.1-2
- fix _smp_mflags macro useage

* Wed Jun 19 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.1-1
- 4.1.0 rc1
- Related: rhbz#971321 failing tests on ppc and s390

* Sun Jun 16 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-9.beta2
- Resolves: rhbz#971321 failing tests on ppc and s390
- Resolves: rhbz#974062 incorrect rendering of text in outline blocks in
  Impress

* Fri Jun 07 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-8.beta2
- Related: rhbz#971795 go back to BR: harfbuzz-devel

* Fri Jun 07 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-7.beta2
- Resolves: rhbz#971230 Use BR: harfbuzz-icu-devel

* Wed Jun 05 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-7.beta1
- 4.1.0 beta2

* Wed Jun 05 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.0-6.beta1
- Related: rhbz#968892 discard impossible languages for Oriya script

* Tue Jun 04 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.0-5.beta1
- Resolves: rhbz#968892 block entire grapheme together for glyph fallback
- Related: rhbz#968892 discard impossible languages for glyph fallback

* Fri May 31 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.1.0.0-4.beta1
- Resolves: rhbz#968976 fix dropdown list autosizing

* Thu May 30 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-3.beta1
- build fix for s390

* Fri May 24 2013 David Tardon <dtardon@redhat.com> - 1:4.1.0.0-2.beta1
- 4.1.0 beta1

* Fri May 24 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.0.3.3-3
- Resolves: rhbz#961460 can't save WebDAV (davs) files

* Thu May 16 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.3.3-2
- Resolves: rhbz#963276 font options cache crash

* Fri May 03 2013 David Tardon <dtardon@redhat.com> - 1:4.0.3.3-1
- 4.0.3 rc3

* Tue Apr 30 2013 David Tardon <dtardon@redhat.com> - 1:4.0.3.2-1
- 4.0.3 rc2

* Mon Apr 22 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.0.3.1-2
- Resolves: rhbz#954991 Avoid static data (causing trouble at exit)

* Thu Apr 18 2013 David Tardon <dtardon@redhat.com> - 1:4.0.3.1-1
- 4.0.3 rc1
- Resolves: rhbz#867808 do not throw UNO exceptions by pointer in C++

* Tue Apr 16 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.2.2-4
- Resolves: rhbz#927223 syntax highlighting crash

* Mon Apr 08 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.2.2-3
- Resolves: rhbz#949238 div by zero on pagedown in 0 width panel

* Fri Apr 05 2013 Kalev Lember <kalevlember@gmail.com> - 1:4.0.2.2-2
- Resolves: rhbz#949106 libreoffice drags in both openjdk 1.7.0 and 1.8.0

* Thu Mar 28 2013 David Tardon <dtardon@redhat.com> - 1:4.0.2.2-1
- 4.0.2 rc2
- Resolves: rhbz#876742 manipulation with larger tables in impress is
  very slow

* Fri Mar 15 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.2.1-2
- Resolves: rhbz#906137 slide show inverts outputs

* Fri Mar 15 2013 David Tardon <dtardon@redhat.com> - 1:4.0.2.1-1
- 4.0.2 rc1
- Resolves: rhbz#921716 Build Breton language pack

* Wed Mar 13 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.0.1.2-4
- Resolves: rhbz#895690 failure saving to gvfs mounts

* Tue Mar 12 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.1.2-3
- Resolves: rhbz#920697 presentation not always full-screen

* Thu Mar 07 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.1.2-2
- Related: rhbz#902884 check for NULL GetSelectedMasterPage
- Resolves: fdo#61241 force area page to size itself
- Resolves: fdo#61656 use order and orientation combobox
- Resolves: fdo#56031 RSID attr changes drop content changes

* Thu Feb 28 2013 David Tardon <dtardon@redhat.com> - 1:4.0.1.2-1
- 4.0.1 rc2

* Tue Feb 26 2013 Eike Rathke <erack@redhat.com> - 1:4.0.0.3-8
- do not access vector elements beyond size, rhbz#847519 related
- Resolves: rhbz#742780 let make OPT_FLAGS=... override SDK flags
- Resolves: rhbz#907933 crash on removing second last para

* Tue Feb 19 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.0.3-7
- Resolves: rhbz#895196 sc filter float a11y parent of itself

* Tue Feb 19 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.3-6
- Resolves: rhbz#911896 add Kazakh localization

* Fri Feb 15 2013 Caolán McNamara <caolanm@redhat.com> - 1:4.0.0.3-5
- make evolution 3.6 work with address book
- Resolves: rhbz#910176 cannot select directory with gtk folder picker
- fixes for building against Boost 1.53.0

* Fri Feb 15 2013 Stephan Bergmann <sbergman@redhat.com> - 1:4.0.0.3-4
- Resolves: fdo#60491 missing libemboleobj.so
- Resolves: rhbz#908674 crash on start

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1:4.0.0.3-3
- Rebuild for Boost-1.53.0

* Wed Feb 06 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.3-2
- fix parsing errors in translated help

* Fri Feb 01 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.3-1
- 4.0.0 rc3

* Wed Jan 23 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.2-1
- 4.0.0 rc2
- use ucpp again

* Tue Jan 22 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.1-3
- Resolves: rhbz#760765 Impress doesn't copy custom styles from one file
  to another

* Mon Jan 21 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.1-2
- Resolves: rhbz#901346 do not install 512x512 icons

* Tue Jan 15 2013 David Tardon <dtardon@redhat.com> - 1:4.0.0.1-1
- 4.0.0 rc1

* Sat Dec 22 2012 David Tardon <dtardon@redhat.com> - 1:4.0.0.0-4.beta2
- use system cpp instead of ucpp

* Wed Dec 19 2012 David Tardon <dtardon@redhat.com> - 1:4.0.0.0-3.beta2
- 4.0.0 beta2

* Thu Dec 06 2012 David Tardon <dtardon@redhat.com> - 1:4.0.0.0-2.beta1
- 4.0.0 beta1

* Thu Nov 29 2012 David Tardon <dtardon@redhat.com> - 1:3.6.4.3-1
- 3.6.4 rc3

* Wed Nov 28 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.4.1-2
- fix docx import on big endian

* Sun Nov 18 2012 David Tardon <dtardon@redhat.com> - 1:3.6.4.1-1
- 3.6.4 rc1

* Wed Nov 14 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.2-8
- Resolves: rhbz#872815 ogltrans effects still suboptimal

* Tue Nov 13 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.2-7
- big endian test failure

* Thu Nov 08 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.2-6
- Resolves: fdo#56198/rhbz#868002 honour gtk-scrollbar-warp-preference

* Tue Nov 06 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.2-5
- bump for libexttextcat

* Fri Nov 02 2012 David Tardon <dtardon@redhat.com> - 1:3.6.3.2-4
- Resolves: rhbz#871929 add keywords to desktop files
- fix debuginfo

* Wed Oct 31 2012 Eike Rathke <erack@redhat.com> - 1:3.6.3.2-3
- Resolves: rhbz#865058 increase number of user-defined format codes

* Fri Oct 26 2012 David Tardon <dtardon@redhat.com> - 1:3.6.3.2-2
- Resolves: rhbz#824035 do not bundle saxon

* Wed Oct 24 2012 David Tardon <dtardon@redhat.com> - 1:3.6.3.2-1
- 3.6.3 rc2
- drop integrated 0001-Resolves-rhbz-868479-fdo-56281-doubled-in-German-ok-.patch

* Mon Oct 22 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.1-3
- Resolves: rhbz#868479 guard against duplicated ~ in OK/Cancel

* Thu Oct 11 2012 David Tardon <dtardon@redhat.com> - 1:3.6.3.1-2
- Resolves: rhbz#858641 backport gstreamer 1.0 support to F-18

* Thu Oct 11 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.3.1-1
- 3.6.3 rc1
- drop integrated 0001-Resolves-rhbz-855972-crash-on-switching-to-outline-v.patch
- drop integrated 0001-fdo-52022-Simple-LargeControlPoints-actually-can-hav.patch
- drop integrated 0001-fdo-46071-Do-not-hide-windows-based-on-nil-Visible-p.patch

* Fri Oct 05 2012 Stephan Bergmann <sbergman@redhat.com> - 1:3.6.2.2-3
- Resolves: fdo#46071 Do not hide windows based on nil Visible property

* Fri Oct 05 2012 Stephan Bergmann <sbergman@redhat.com> - 1:3.6.2.2-2
- Resolves: fdo#52022 Part of data in userdir is lost on upgrade

* Wed Sep 26 2012 David Tardon <dtardon@redhat.com> - 1:3.6.2.2-1
- 3.6.2 rc2

* Wed Sep 12 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.2.1-2
- Resolves: rhbz#855541 XIOError handler multithread woes

* Wed Sep 12 2012 David Tardon <dtardon@redhat.com> - 1:3.6.2.1-1
- 3.6.2 rc1

* Tue Sep 11 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.1.2-4
- Resolves: rhbz#855507 large ole2 compound files fail to load

* Mon Sep 10 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.1.2-3
- Resolves: rhbz#855972 crash on switching to outline view

* Wed Aug 29 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.1.2-2
- Related: rhbz#850709 hunspell en-US available standalone so
  make English langpack require hunspell-en and core just
  bare bones hunspell-en-US

* Sun Aug 26 2012 David Tardon <dtardon@redhat.com> - 1:3.6.1.2-1
- 3.6.1 rc2

* Wed Aug 22 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.1.1-2
- Resolves: rhbz#846775 Clipboard must be disposed before selection
- Resolves: rhbz#842292 crash in scrolling multiselection in draw

* Wed Aug 15 2012 David Tardon <dtardon@redhat.com> - 1:3.6.1.1-1
- 3.6.1 rc1

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> - 1:3.6.0.4-3
- Rebuild for new boost

* Sat Jul 28 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.4-2
- rebuilt for boost 1.50

* Fri Jul 27 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.4-1
- 3.6.0 rc4

* Thu Jul 26 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.3-2
- Resolves: rhbz#842552 crash in pptx import

* Wed Jul 25 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.3-1
- 3.6.0 rc3

* Tue Jul 17 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.2-1
- 3.6.0 rc2

* Mon Jul 16 2012 Caolán McNamara <caolanm@redhat.com> - 1:3.6.0.1-3
- Resolves: rhbz#836937 insanely slow with Zemberek

* Mon Jul 16 2012 David Tardon <dtardon@redhat.com> - 1:3.6.0.1-2
- rebuild for new libexttextcat

* Thu Jul 12 2012 David Tardon <dtardon@redhat.com> - 3.6.0.1-1
- 3.6.0 rc1

* Mon Jul 09 2012 Caolán McNamara <caolanm@redhat.com> - 3.6.0.0-4
- Resolves: rhbz#838368 --view ignored while -view accepted

* Thu Jul 05 2012 David Tardon <dtardon@redhat.com> - 3.6.0.0-3
- 3.6.0 beta3

* Mon Jul  2 2012 Marek Kasik <mkasik@redhat.com> - 3.6.0.0-2
- Rebuild (poppler-0.20.1)

* Wed Jun 27 2012 David Tardon <dtardon@redhat.com> - 3.6.0.0-1
- 3.6.0 beta2
- drop integrated 0001-move-binfilter-mime-types-into-extra-.desktop-file.patch
- drop integrated 0001-Resolves-rhbz-788042-skip-splashscreen-with-quicksta.patch
- drop integrated libreoffice-ensure-non-broken-xml-tree.patch
- drop integrated 0001-preserve-timestamps-for-.py-files.patch
- drop integrated 0001-Resolves-rhbz-788045-swriter-help-etc-doesn-t-show-h.patch
- drop integrated 0001-Resolves-rhbz-799525-put-flat-odf-mimetypes-in-xsltf.patch
- drop integrated 0001-Resolves-rhbz-800272-complain-about-unknown-command-.patch
- drop integrated 0001-Resolves-rhbz-806663-SlideshowImpl-can-outlive-SdMod.patch
- drop integrated 0001-desktop-do-not-complain-about-soffice-command-line-o.patch
- drop integrated 0001-Resolves-fdo-48096-torn-off-popups-trigger-keyboard-.patch
- drop integrated 0001-fdo-38088-better-CSV-import-default-separators.patch
- drop integrated 0001-save-register-arguments-first.patch
- drop integrated 0001-do-not-let-gcc-use-registers-we-are-setting-ourselve.patch
- drop integrated 0001-wrong-types-used-here-breaks-64bit-bigendian.patch
- drop integrated 0001-Resolves-rhbz-805743-a11y-call-doShow-after-we-have-.patch
- drop integrated 0001-Resolves-fdo-49849-implement-Unicode-6.1-hebrew-line.patch
- drop integrated 0001-use-ure-instead-of-ure-link.patch
- drop broken 0001-fix-setting-of-paper-tray-from-print-dialog-fdo-4393.patch

* Mon Jun 18 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.5.1-2
- Resolves: rhbz#830810 missing dependency on lucene-contrib

* Thu Jun 14 2012 David Tardon <dtardon@redhat.com> - 3.5.5.1-1
- 3.5.5 rc1
- drop integrated 0001-make-hsqldb-build-with-java-1.7.patch
- drop integrated 0001-Related-rhbz-799628-crash-with-chewing-IM-with-g3g.patch
- drop integrated 0001-silence-SolarMutex-not-locked-spew.patch
- drop integrated 0001-gcc-trunk-fix-unable-to-find-string-literal-operator.patch
- drop integrated 0001-ppc-yyinput-returns-a-int-truncating-to-unsigned-cha.patch
- drop integrated 0001-Resolves-rhbz-826609-rhbz-820554-fix-smoketest-on-pp.patch

* Mon Jun 11 2012 David Tardon <dtardon@redhat.com> - 3.5.4.2-3
- make gdb pretty printers for URE libs usable again

* Fri Jun 08 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.4.2-2
- Resolves: rhbz#826609, rhbz#820554 fix smoketest on ppc[64] and s390[x]

* Wed May 23 2012 David Tardon <dtardon@redhat.com> - 3.5.4.2-1
- 3.5.4 rc2

* Thu May 17 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.4.1-2
- Resolves: rhbz#811226 ARM FTBFS

* Wed May 16 2012 David Tardon <dtardon@redhat.com> - 3.5.4.1-1
- 3.5.4 rc1
- drop integrated 0001-do-not-prepend-n-twice-it-confuses-KFileDialog-rhbz-.patch
- drop integrated 0001-incrementing-index-twice-in-one-run-seems-wrong.patch
- drop integrated 0001-fdo-49365-correctly-map-monitor-index-back-to-screen.patch
- drop integrated 0001-rhbz-809019-count-mirrored-monitors-as-one.patch

* Sun May 13 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.3.2-5
- Resolves: fdo#49849 line breaking fixes for Hebrew

* Fri May 11 2012 David Tardon <dtardon@redhat.com> - 3.5.3.2-4
- Resolves: rhbz#820439 KDE export dialog broken for most formats
- Resolves: fdo#49365 Libreoffice fails to start on second screen with
  gtk vcl plugin
- Resolves: rhbz#809019 Impress thinks a machine with 2 monitors in
  clone mode is multihead

* Wed May 09 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.3.2-3
- Resolves: rhbz#805743 a11y crash in impress/draw
- Resolves: rhbz#813202 opengl slide transitions still a bit
  problematic in Fedora 17

* Thu May 03 2012 David Tardon <dtardon@redhat.com> - 3.5.3.2-2
- rebuild for changed dependencies

* Wed Apr 25 2012 David Tardon <dtardon@redhat.com> - 3.5.3.2-1
- 3.5.3 rc2
- fix broken test on 64bit big endian

* Mon Apr 23 2012 David Tardon <dtardon@redhat.com> - 3.5.3.1-2
- rebuild for icu
- fix UNO bridges for ppc and ppc64

* Thu Apr 19 2012 David Tardon <dtardon@redhat.com> - 3.5.3.1-1
- 3.5.3 rc1
- drop integrated 0001-Introduced-SystemShellExecuteFlags-URIS_ONLY.patch
- drop integrated 0001-Simplify-code-and-use-proper-register-names-for-linu.patch
- drop integrated 0001-resolved-rhbz-813280-the-current-document-is-not-alw.patch

* Wed Apr 18 2012 Eike Rathke <erack@redhat.com> - 3.5.2.1-7
- Resolves: rhbz#813280 sheets cannot be moved in Calc

* Wed Apr 11 2012 Eike Rathke <erack@redhat.com> - 3.5.2.1-6
- Resolves: fdo#38088 rhbz#810267 better CSV import default separators

* Tue Apr 10 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.2.1-5
- Resolves: rhbz#811226 FTBFS ARM

* Thu Apr 05 2012 Stephan Bergmann <sbergman@redhat.com> - 3.5.2.1-4
- Fix URIS_ONLY flag issue
- rebuild for db4

* Mon Apr 02 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.2.1-3
- Resolves: rhbz#708041 focus problems with tearable menus

* Mon Mar 26 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.2.1-2
- Resolves: rhbz#806663 SlideshowImpl can outlive SdModule

* Sun Mar 25 2012 David Tardon <dtardon@redhat.com> - 3.5.2.1-1
- 3.5.2 rc1
-drop integrated 0001-yet-another-clash-with-macro-name.patch

* Wed Mar 14 2012 David Tardon <dtardon@redhat.com> - 3.5.1.2-2
- Resolves: rhbz#770209 can't change paper tray setting while printing

* Thu Mar 08 2012 David Tardon <dtardon@redhat.com> - 3.5.1.2-1
- 3.5.1 rc2

* Tue Mar 06 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.1.1-3
- Resolves: rhbz#799628 crash with chewing IM with g3g
- Resolves: rhbz#799525 put flat odf mimetypes into xsltfilter.desktop
- Resolves: rhbz#800272 complain about unknown commandline options

* Wed Feb 29 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.1.1-2
- Resolves: rhbz#788045 swriter --help doesn't show help
- Resolves: rhbz#798667 missing .desktop icons

* Sun Feb 26 2012 David Tardon <dtardon@redhat.com> - 3.5.1.1-1
- 3.5.1 rc1
- drop 0001-Resolves-fdo-43644-survive-registered-but-unavailabl.patch
- drop 0001-Resolves-rhbz-789622-Adapt-SDK-to-changed-paths-in-L.patch
- drop 0001-Fix-fdo-45177-avoid-linked-undo-for-the-while.patch
- drop 0001-Fix-some-apparent-misuses-of-RTL_CONSTASCII_USTRINGP.patch
- drop binfilter-Fix-some-apparent-misuses-of-RTL_CONSTASCII_USTRINGP.patch
- Resolves: fdo#45177 avoid linked undo crash
- Fix some apparent misuses of RTL_CONSTASCII_USTRINGPARAM (cherry-picked from
  upstream libreoffice-3-5 branch)

* Tue Feb 14 2012 Stephan Bergmann <sbergman@redhat.com> - 3.5.0.3-5
- Resolves rhbz#789622: Adapt SDK to changed paths in LO installation

* Mon Feb 13 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.0.3-4
- ensure gdb .py files have the same timstamps so that multilib
  .pyc's and .pyo's have the same content (timestamp in binary cache)

* Sat Feb 11 2012 Caolán McNamara <caolanm@redhat.com> - 3.5.0.3-3
- make sure .tree files don't get busted again

* Tue Feb 07 2012 Stephan Bergmann <sbergman@redhat.com> - 3.5.0.3-2
- junit4 -> junit
- Resolves: rhbz#788042 skip splashscreen with quickstarter
- with split binfilter we need fix for fdo#43644

* Thu Feb 02 2012 David Tardon <dtardon@redhat.com> - 3.5.0.3-1
- 3.5.0 rc3
- Resolves: rhbz#786328 add nlpsolver subpackage
- split legacy binary filters into subpackage

* Thu Jan 26 2012 Stephan Bergmann <sbergman@redhat.com> - 3.5.0.2-2
- add libreoffice-postgresql subpackage

* Wed Jan 25 2012 David Tardon <dtardon@redhat.com> - 3.5.0.2-1
- 3.5.0 rc2

* Thu Jan 19 2012 David Tardon <dtardon@redhat.com> - 3.5.0.1-1
- 3.5.0 rc1
- drop integrated 0001-workaround-internal-compiler-error-with-gcc-4.7.patch
- drop integrated 0001-fix-for-gcc-4.7-C-11-these-are-not-string-literal-op.patch
- drop integrated 0001-fix-for-gcc-4.7-C-11-this-is-not-string-literal-oper.patch
- drop integrated 0001-Revert-fast_merge-fix-mis-merge-of-first-module-s-st.patch
- drop integrated 0001-fix-writing-of-strings-from-the-first-module.patch
- drop integrated 0001-refactor-slightly-to-avoid-link-problems-with-gcc-4..patch

* Fri Jan 13 2012 David Tardon <dtardon@redhat.com> - 3.4.99.3-1
- 3.5.0 beta3
- drop integrated 0001-fix-syntactic-error.patch
- drop integrated 0001-gcc-trunk-fix-error-unable-to-find-string-literal-op.patch
- drop integrated 0001-gcc-trunk-avoid-confusion.patch
- drop integrated 0001-workaround-for-LO-namespace-pollution-breaking-KDE4-.patch
- drop integrated 0001-smath-does-not-handle-accents-in-MathML.patch
- Resolves: rhbz#533318 smath does not handle accents in MathML
- Resolves: rhbz#771108 English menu in writer despite installation of
  libreoffice-langpack-de

* Fri Jan 06 2012 David Tardon <dtardon@redhat.com> - 3.4.99.2-2
- rebuild with gcc 4.7

* Wed Dec 21 2011 David Tardon <dtardon@redhat.com> - 3.4.99.2-1
- 3.5.0 beta2
- drop integrated 0001-Resolves-rhbz-761009-IFSD_Equal-is-asymmetrical.patch
- drop integrated 0001-Resolves-rhbz-767708-avoid-SIGBUS-writing-to-overcom.patch
- drop integrated 0001-force-gbuild-stage-for-CustomTargets.patch
- drop integrated 0001-these-translations-do-already-exist-in-translations-.patch
- drop integrated 0001-Fix-typo-and-clean-up.patch
- use system mysql-connector-c++

* Sun Dec 18 2011 David Tardon <dtardon@redhat.com> - 3.4.99.1-1
- 3.5.0 beta1
- drop integrated 0001-Related-fdo-37195-migrationoo3-not-registered.patch
- drop integrated 0001-Related-i58612-don-t-crash-anyway.patch
- drop integrated 0001-Related-rhbz-652604-better-survive-exceptions-thrown.patch
- drop integrated 0001-Related-rhbz-702833-addEventListener-without-removeE.patch
- drop integrated 0001-Related-rhbz-711087-band-aid.patch
- drop integrated 0001-Related-rhbz-718976-crash-in-SwTxtSizeInfo-GetMultiC.patch
- drop integrated 0001-Related-rhbz-730225-avoid-segv-in-ld-this-was-set-to.patch
- drop integrated 0001-Related-rhbz-753201-fedora-ant-java-1.5.0-gcj-won-t-.patch
- drop integrated 0001-Resolves-fdo-32665-handle-that-FreeSerif-lacks-some-.patch
- drop integrated 0001-Resolves-rhbz-693265-fix-crash-from-unhandled-except.patch
- drop integrated 0001-Resolves-rhbz-695509-crash-in-RefreshDocumentLB.patch
- drop integrated 0001-Resolves-rhbz-713154-pdf-export-dialog-too-tall-to-f.patch
- drop integrated 0001-Resolves-rhbz-715549-use-fontconfig-s-detected-forma.patch
- drop integrated 0001-Resolves-rhbz-738255-avoid-crash-on-NULL-pointer.patch
- drop integrated 0001-Resolves-rhbz-751290-KDE-black-on-dark-tooltips.patch
- drop integrated 0001-add-Oracle-Java-1.7.0-recognition.patch
- drop integrated 0001-avoid-using-com.sun.org-apis.patch
- drop integrated 0001-bubble-down-configure-test-findings-on-visibility.patch
- drop integrated 0001-fix-horizontal-scrollbars-with-KDE-oxygen-style-bnc-.patch
- drop integrated 0001-gtk3-fix-cairo-canvas-crash-for-non-X-or-svp-backend.patch
- drop integrated 0001-helgrind-Related-rhbz-655686-get-order-of-shutdown-c.patch
- drop integrated 0001-rhbz-667082-do-not-crash-importing-section-containin.patch
- drop integrated 0001-rhbz-702635-set-correct-page-number-when-exporting-s.patch
- drop integrated Backport-reading-AES-encrypted-ODF-1.2-documents.patch
- drop integrated gdb-pretty-printers.patch
- drop integrated kde4configure.patch
- drop integrated libreoffice-ppc64.patch
- drop integrated openoffice.org-3.3.0.ooo108637.sfx2.uisavedir.patch
- drop integrated openoffice.org-3.3.0.ooo113273.desktop.resolvelinks.patch
- drop integrated vbahelper.visibility.patch
- drop libreoffice-testtools subpackage, because testtool has been
  removed by upstream

* Thu Dec 15 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.4.2-6
- Resolves: rhbz#761009 IFSD_Equal is asymmetrical
- Resolves: rhbz#767708 write to mmap'ed file w/o disk space: SIGBUS

* Tue Nov 29 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.4.2-5
- Resolves: rhbz#757653 fix headless crash with cairo canvas

* Tue Nov 22 2011 Lukas Tinkl <ltinkl@redhat.com> - 3.4.4.2-4
- Resolves: rhbz#751290 - [kde] LibreOffice has black on dark-grey tooltip-texts

* Fri Nov 11 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.4.2-3
- Related: fdo#42534 0001-Related-i58612-don-t-crash-anyway.patch
- Resolves: fdo#42749 KDE oxygen theme and scrollbars

* Thu Nov 10 2011 Stephan Bergmann <sbergman@redhat.com> - 3.4.4.2-2
- Patch to backport reading AES-encrypted ODF 1.2 documents

* Thu Nov 03 2011 David Tardon <dtardon@redhat.com> - 3.4.4.2-1
- 3.4.4 rc2

* Fri Oct 28 2011 Rex Dieter <rdieter@fedoraproject.org> - 1:3.4.4.1-4
- rebuild(poppler)

* Thu Oct 27 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.4.1-3
- Resolves: rhbz#665800 missing glyph symbol shown when toggling bold/italic
  for Sinhala text

* Thu Oct 27 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.4.1-2
- possible fix for java 1.7.0 detection


* Wed Oct 26 2011 David Tardon <dtardon@redhat.com> - 3.4.4.1-1
- 3.4.4 rc1

* Tue Oct 25 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-16
- allow building with gcj

* Fri Oct 21 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-15
- Resolves: rhbz#747356 let Qt call XInitThreads
- fix .sdw import

* Wed Oct 19 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-14
- Related: rhbz#743750 addXineramaScreenUnique issue
 
* Fri Oct 07 2011 Stephan Bergmann <sbergman@redhat.com> - 3.4.3.2-13
- Patches to build with GCC 6.4.1

* Fri Sep 30 2011 Marek Kasik <mkasik@redhat.com> - 3.4.3.2-12
- Rebuild (poppler-0.18.0)

* Tue Sep 20 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-11
- Resolves: rhbz#738133 fix bn discard string
- Resolves: fdo#35513 avoid crash while processing incorrect print range

* Mon Sep 19 2011 Marek Kasik <mkasik@redhat.com> - 3.4.3.2-10
- Rebuild (poppler-0.17.3)

* Thu Sep 15 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-9
- Resolves: rhbz#738255 avoid crash on sc inputhdl

* Tue Sep 13 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-8
- Resolves: rhbz#274631 remove NoDisplay from -math.desktop

* Thu Sep 08 2011 David Tardon <dtardon@redhat.com> - 3.4.3.2-7
- rebuild for new icu

* Tue Sep 06 2011 David Tardon <dtardon@redhat.com> - 3.4.3.2-6
- Resolves: rhbz#734976 libreoffice-langpack-*-* not pulled in by
  yum install libreoffice

* Fri Sep 02 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-5
- Resolves: rhbz#735182 be able to rebuild against poppler 0.17.3

* Tue Aug 30 2011 David Tardon <dtardon@redhat.com> - 3.4.3.2-4
- Resolves: rhbz#734432 openoffice.org symlink broken

* Mon Aug 29 2011 David Tardon <dtardon@redhat.com> - 3.4.3.2-3
- add Latvian langpack

* Fri Aug 26 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.3.2-2
- Resolves: rhbz#733564 graphite2 now packaged into fedora
- Related: fdo#37195 migrationoo3 not registered

* Thu Aug 25 2011 David Tardon <dtardon@redhat.com> - 3.4.3.2-1
- 3.4.3 rc2

* Mon Aug 22 2011 David Tardon <dtardon@redhat.com> - 3.4.3.1-2
- add gdb pretty printers

* Tue Aug 16 2011 David Tardon <dtardon@redhat.com> - 3.4.3.1-1
- 3.4.3 rc1
- drop integrated 0001-Resolves-rhbz-725144-wrong-csh-syntax.patch

* Fri Aug 12 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.2.3-3
- Related: rhbz#730225 avoid segv in ld

* Tue Aug 02 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.2.3-2
- Resolves: rhbz#693265 fix crash from unhandled exception

* Fri Jul 29 2011 David Tardon <dtardon@redhat.com> - 3.4.2.3-1
- 3.4.2 rc3

* Mon Jul 25 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.2.2-2
- Resolves: rhbz#725144 wrong csh syntax

* Wed Jul 20 2011 David Tardon <dtardon@redhat.com> - 3.4.2.2-1
- 3.4.2 rc2
- fix breakage in KDE4 plugin

* Tue Jul 19 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.2.1-3
- Resolves: rhbz#715549 use fontconfig's detected format

* Mon Jul 18 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.2.1-2
- Rebuild (poppler-0.17.0), add libreoffice-poppler-0.17.0.patch
  seeing as the API changed for some reason or other

* Wed Jul 13 2011 David Tardon <dtardon@redhat.com> - 3.4.2.1-1
- 3.4.2 rc1
- drop 0001-bad-merge-fix-to-enable-extensions-to-build-again.patch
- drop 0001-fix-regression-in-SvGlobalName-operator.patch

* Tue Jul 12 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.3-3
- fix regression in SvGlobalName operator

* Tue Jul 05 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.3-2
- Related: rhbz#718976 crash in SwTxtSizeInfo::GetMultiCreator

* Fri Jul 01 2011 David Tardon <dtardon@redhat.com> - 3.4.1.3-1
- 3.4.1 rc3

* Thu Jun 23 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.2-1
- 3.4.1 rc2
- drop integrated 0001-correctly-build-GTK-systray-icon.patch

* Tue Jun 21 2011 David Tardon <dtardon@redhat.com> - 3.4.1.1-5
- Resolves: rhbz#714781 add Persian langpack
- Resolves: rhbz#667082 do not crash importing section containing just
  an empty paragraph

* Mon Jun 20 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.1-4
- Related: rhbz#711087 band aid for crash in sc undo
- Resolves: rhbz#714338 add a metapackage to install standard bits

* Fri Jun 17 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.1-3
- Related: rhbz#702833 addEventListener without removeEventListener

* Thu Jun 16 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.1.1-2
- Resolves: rhbz#713154 pdf export dialog too tall to fit

* Wed Jun 15 2011 David Tardon <dtardon@redhat.com> - 3.4.1.1-1
- 3.4.1 RC1
- drop integrated 0001-Resolves-rhbz-707317-avoid-crash-in-getRowSpan.patch
- drop integrated 0001-Resolves-rhbz-710004-band-aid-for-immediate-crash-in.patch
- drop integrated 0001-Resolves-rhbz-710556-don-t-crash-on-missing-graphics.patch
- drop integrated 0001-Resolves-rhbz-699909-crash-in-export-of-.doc-in-lcl_.patch
- drop integrated 0001-fdo-37584-Make-a-real-copy-of-the-text-where-to-coun.patch
- drop integrated 0001-Resolves-fdo-37668-bitwise-operations-on-signed-numb.patch

* Thu Jun 09 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.0.2-5
- Resolves: rhbz#699909 crash in export of .doc in lcl_getField
- Resolves: fdo#37584 Make a real copy of the text
- Resolves: rhbz#709503/fdo#37668 bitwise operations on signed values

* Tue Jun 07 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.0.2-4
- Resolves: rhbz#710556 't crash on missing graphics .pptx export
- Resolves: rhbz#652604 better survive exceptions in autorecovery

* Thu Jun 02 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.0.2-3
- Resolves: rhbz#710004 band aid for crash

* Mon May 30 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.0.2-2
- Resolves: rhbz#707317 avoid crash in getRowSpan

* Fri May 27 2011 David Tardon <dtardon@redhat.com> - 3.4.0.2-1
- 3.4.0 RC2
- drop integrated 0001-fix-build-with-system-bsh.patch

* Wed May 25 2011 Caolán McNamara <caolanm@redhat.com> - 3.4.0.1-3
- rebuild for new hunspell

* Tue May 24 2011 David Tardon <dtardon@redhat.com> - 3.4.0.1-2
- Resolves: rhbz#706110 oosplash.bin segfault on every login

* Fri May 20 2011 David Tardon <dtardon@redhat.com> - 3.4.0.1-1
- 3.4 RC1
- Resolves: rhbz#702635 set correct page number when exporting selected
  pages

* Sat May 07 2011 Christopher Aillon <caillon@redhat.com> - 3.3.99.4-2
- Update icon cache scriptlet

* Sat May 07 2011 David Tardon <dtardon@redhat.com> 3.3.99.4-1
- 3.4 beta4
- drop integrated 0001-Removed-duplicate-code-block-mis-merge-prolly.patch
- drop integrated 7de0b88ce2dd932915894385b54be1897d5ee053.zip

* Mon Apr 18 2011 Caolán McNamara <caolanm@redhat.com> 3.3.99.1-2
- Resolves: rhbz#695509 crash in RefreshDocumentLB
- bubble down configure test findings on visibility

* Mon Apr 11 2011 Caolán McNamara <caolanm@redhat.com> 3.3.99.1-1
- 3.4 beta1
- drop openoffice.org-1.9.123.ooo53397.prelinkoptimize.desktop.patch
  in favour of ooosplash
- drop openoffice.org-2.2.0.gccXXXXX.solenv.javaregistration.patch
  because components are passively registered now
- drop integrated openoffice.org-3.1.0.ooo102061.sc.cellanchoring.patch
- drop integrated turn-script-providers-into-extensions.patch
- drop integrated 0001-tidy-this-up-and-don-t-bail-out-on-mislength-records.patch
- drop integrated 0001-free-ctxt-after-taking-lastError-details.patch
- drop integrated 0001-Removed-suspect-hack.-Cursor-on-post-it-now-scrolls-.patch
- drop integrated libreoffice-gcc4.6.0.patch
- drop integrated 0001-fexceptions-fexceptions.patch
- drop integrated 0001-Related-rhbz-672872-cancel-gtk-file-dialog-on-deskto.patch
- drop vbahelper.visibility.patch
- drop integrated 0001-Resolves-fdo-33509-i62414-out-by-one-breaks-CTL-spel.patch
- drop integrated 0001-Resolves-rhbz-670020-crash-in-slidesorting.patch
- drop integrated 0001-Resolves-rhbz-676539-handle-missing-pWindows-from-xW.patch
- drop integrated 0001-Resolves-fdo-33750-i94623-use-optimal-border-width-w.patch
- drop integrated 0001-rhbz-649310-don-t-crash-deregistering-diff.-platform.patch
- drop integrated 0001-Resolves-rhbz-674330-dereference-of-NULL-mpBase.patch
- drop integrated 0001-rhbz-678284-Get-correct-current-position-when-shift-page-up-and-.patch
- drop integrated 0001-Resolves-rhbz-681159-bandaid-for-crash.patch
- drop integrated 0001-Resolves-rhbz-672818-bandaid-for-crash-in-SwTxtNode-.patch
- drop integrated 0001-install-high-resolution-icons.patch
- drop integrated 0001-Resolves-rhbz-682716-pa-IN-isn-t-handled-by-fontconf.patch
- drop integrated 0001-Related-rhbz-684477-make-sure-this-is-thread-safe.patch
- drop integrated 0001-Resolves-rhbz-682621-better-resizing-of-overtall-gly.patch
- drop integrated 0001-Resolves-rhbz-684620-crash-with-NULL-pTableBox.patch
- drop integrated libreoffice-fdo33947.sd.print.crash.patch
- drop integrated 0001-add-cairo_ft_font_face_create_for_pattern-wrapper.patch
- drop integrated 0001-Related-rhbz-680460-reorganize-this-to-make-it-inher.patch
- drop integrated 0001-Related-rhbz-680460-don-t-bother-with-an-interim-Fon.patch
- drop integrated 0001-Resolves-rhbz-680460-honour-lcdfilter-subpixeling-et.patch
- drop integrated 0001-Cut-Gordian-Knot-of-who-owns-the-font-options.patch
- drop integrated 0001-beware-of-invalidated-iterator.patch
- drop integrated rhbz680766.fix-mdds-crash.patch
- drop integrated 0001-Resolves-rhbz-684580-X-and-strike-through-escapes-ra.patch
- drop integrated 0001-set-mime-types-on-flat-xml-filters.patch
- drop integrated 0001-add-flat-xml-types-to-.desktop-files-etc.patch
- drop integrated libreoffice-fdo31271.icu.patch

* Tue Apr 05 2011 Caolán McNamara <caolanm@redhat.com> 3.3.2.2-6
- Resolves: rhbz#655686 get order of shutdown correct

* Wed Mar 30 2011 Caolán McNamara <caolanm@redhat.com> 3.3.2.2-5
- Add application/vnd.oasis.opendocument.text-flat-xml, etc. to
  .desktop files for mcepl

* Tue Mar 29 2011 Caolán McNamara <caolanm@redhat.com> 3.3.2.2-4
- Resolves: rhbz#684580 improve X and / strike-through

* Thu Mar 24 2011 David Tardon <dtardon@redhat.com> 3.3.2.2-3
- Resolves: rhbz#680766 crash in mdds

* Wed Mar 23 2011 David Tardon <dtardon@redhat.com> 3.3.2.2-2
- Related: rhbz#689268 versioned deps need to contain epoch

* Tue Mar 22 2011 Caolán McNamara <caolanm@redhat.com> 3.3.2.2-1
- latest version
- drop integrated 0001-Resolves-fdo-33701-ensure-node-outlives-path.patch
- drop integrated 0001-valgrind-don-t-leave-an-evil-thread-running-after-ma.patch

* Tue Mar 22 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-12
- Fix fontoptions cache
- avoid crash in calc on changing size of rows (dtardon)

* Mon Mar 21 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-11
- Resolves: rhbz#689268 autocorrs from OOo F14 not upgraded

* Wed Mar 16 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-10
- Resolves: rhbz#680460 honour lcdfilter and subpixeling

* Tue Mar 15 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-9
- Resolves: fdo#33947 sd print crash

* Mon Mar 14 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-8
- Related: rhbz#684477 make sure this is thread safe
- Resolves: rhbz#684620 crash with NULL pTableBox

* Sun Mar 13 2011 Marek Kasik <mkasik@redhat.com> 3.3.1.2-7
- Rebuild (poppler-0.16.3)

* Wed Mar 09 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-6
- Resolves: rhbz#682621 better resizing of overtall glyphsubs

* Tue Mar 08 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-5
- Resolves: rhbz#682716 pa-IN isn't handled well by fontconfig

* Tue Mar 08 2011 David Tardon <dtardon@redhat.com> 3.3.1.2-4
- install 128x128 px icons

* Wed Mar 02 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-3
- Resolves: rhbz#681159 crash in writer
- Resolves: rhbz#672818 crash in writer
- Resolves: fdo#33701 ensure node outlives path
- Resolves: rhbz#681738 crash on writing config post-main

* Thu Feb 17 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-2
- Resolves: rhbz#678284 Calc crashes during cell select with keys
  (dtardon)

* Thu Feb 17 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.2-1
- RC2

* Wed Feb 16 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.1-2
- Resolves: rhbz#674330 dereference of NULL mpBase

* Fri Feb 11 2011 Caolán McNamara <caolanm@redhat.com> 3.3.1.1-1
- 3.3.1 rc1
- drop integrated 0001-don-t-pushback-and-process-a-corrupt-extension.patch
- drop integrated libreoffice-fdo32561.comphelper.patch
- drop integrated 0001-Related-rhbz-610103-more-woes-on-rpm-upgrade-vs-rpm-.patch
- drop integrated 0001-Resolves-rhbz-673819-crash-on-changing-position-of-d.patch
- drop integrated 0001-rhbz-666440-don-t-pushback-and-process-a-corrupt-extension.patch

* Thu Feb 10 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild
- Related: rhbz#610103 make this even more robust
- Related: rhbz#672872 cancel gtk file dialog on terminate
- Resolves: fdo#33509/ooo#62414 fix CTL spelling popup
- Resolves: rhbz#673819 crash on changing position of header/footer object
- Resolves: rhbz#670020 crash in slidesorting
- Resolves: rhbz#676539 handle missing pWindows from xWindows
- Resolves: rhbz#649310 don't crash deregistering diff. platform ext.
  (dtardon)
- Resolves: rhbz#666440 don't pushback and process a corrupt extension

* Mon Jan 24 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.4-2
- Resolves: rhbz#671540 fix lonely )

* Thu Jan 20 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.4-1
- next release candidate
- drop integrated 0001-fix-presenter-screens-description.xml-build.patch

* Tue Jan 18 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.3-2
- backport fix to get presenter screen working
- make handling busted extensions more robust

* Wed Jan 12 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.3-1
- latest version
- drop integrated 0001-Resoves-rhbz-663857-font-color-missing-C-FAQ-10.3-do.patch
- drop integrated 0001-Avoid-double-paste-when-pasting-text-into-cell-comme.patch
- drop integrated 0001-Resolves-rhbz-660342-Undo-Redo-crash-with-postits.patch
- drop integrated 0001-Resolves-rhbz-666088-clean-up-search-cache-singleton.patch

* Thu Jan 06 2011 Caolán McNamara <caolanm@redhat.com> 3.3.0.2-5
- Resolves: rhbz#666088 don't crash on clean up of search cache

* Wed Jan 05 2011 Lukas Tinkl <ltinkl@redhat.com> 3.3.0.2-4
- create a KDE integration subpackage

* Mon Jan 03 2011 David Tardon <dtardon@redhat.com> 3.3.0.2-3
- rebuild with new poppler

* Wed Dec 22 2010 Caolán McNamara <caolanm@redhat.com> 3.3.0.2-2
- Resolves: rhbz#663724 fdo32572-sc-dont-double-paste.patch
- Resolves: rhbz#660342 Undo/Redo crash with postits

* Tue Dec 21 2010 Caolán McNamara <caolanm@redhat.com> 3.3.0.2-1
- latest version

* Sat Dec 18 2010 Caolán McNamara <caolanm@redhat.com> 3.3.0.1-4
- Resolves: rhbz#663857 font color missing in transitions

* Wed Dec 15 2010 Rex Dieter <rdieter@fedoraproject.org> - 3.3.0.1-3
- rebuild (poppler)

* Wed Dec 15 2010 Caolán McNamara <caolanm@redhat.com> 3.3.0.1-2
- Fix up some doc imports

* Sun Dec 05 2010 Caolán McNamara <caolanm@redhat.com> 3.3.0.1-1
- release candidate 1
- drop integrated qstart.dont-forceenabled-on-post-reg-restart.patch
- drop integrated exit.quickstarter.when.deleted.patch
- drop integrated 0001-destroydesktop.in.timeout.patch
- drop integrated openoffice.org-3.3.0.rhbz657541.join-paragraphs.patch

* Sat Nov 27 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.3-2
- Resolves: rhbz#610103 exit quickstarter when libs deleted
- Resolves: rhbz#652695 release desktop in timeout
- Resolves: rhbz#657541 don't crash during processing of auto. styles
  when joining paragraphs (dtardon)

* Thu Nov 18 2010 Caolán McNamara <caolanm@redhat.com 3.2.99.3-1
- next Libreoffice milestone
- drop integrated openoffice.org-2.0.1.rhXXXXXX.extensions.defaulttoevo2.patch
- drop integrated openoffice.org-2.2.1.ooo7065.sw.titlepagedialog.patch
- drop integrated openoffice.org-3.2.0.ooo108846.sfx2.qstartfixes.patch
- drop integrated openoffice.org-3.3.0.ooo107490.cppu.lifecycle.patch
- drop integrated libreoffice-buildfix.patch
- drop integrated libreoffice-xdg632229.gnomeshell.patch
- drop integrated 0001-strcpy-cannot-be-used-with-overlapping-src-and-dest.patch
- drop integrated 0001-abort-doesn-t-gain-us-anything-here.patch
- drop integrated 0001-latest-libX11-changed-header-guards.patch

* Sat Nov 06 2010 David Tardon <dtardon@redhat.com 3.2.99.2-6
- turn script providers into extensions

* Wed Nov 03 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.2-5
- Resolves: rhbz#649210 add Sinhalese langpack

* Sat Oct 30 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.2-4
- langpack macro hard-coded version number

* Fri Oct 22 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.2-3
- Resolves: xdg632229 gnomeshell app tracking

* Tue Oct 12 2010 David Tardon <dtardon@redhat.com> 3.2.99.2-2
- use macros to define auto-correction and language pack subpackages

* Mon Oct 11 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.2-1
- next LibreOffice milestone
- drop integrated openoffice.org-2.3.0.ooo76649.httpencoding.patch
- drop integrated workspace.dtardon03.patch
- drop integrated openoffice.org-3.1.0.ooo61927.sw.ww6.unicodefontencoding.patch
- drop integrated workspace.impress195.patch
- drop integrated workspace.srb1.patch
- drop integrated openoffice.org-3.2.0.ooo106502.svx.fixspelltimer.patch
- drop integrated openoffice.org-3.3.0.ooo108246.svx.hide-sql-group-when-inactive.patch
- drop integrated openoffice.org-3.2.0.ooo95369.sw.sortedobjs.patch
- drop integrated openoffice.org-3.2.0.ooo110142.svx.safercolornames.patch
- drop integrated openoffice.org-3.3.0.ooo111758.sd.xerror.patch
- drop integrated openoffice.org-3.2.0.ooo111741.extras.malformed-xml-file.patch
- drop integrated openoffice.org-3.3.0.ooo112059.sw.avoid-null-ptr-deref.patch
- drop integrated openoffice.org-3.3.0.ooo100686.wizards.types.not.mediatypes.patch
- drop integrated workspace.vcl113.patch
- drop integrated openoffice.org-3.3.0.ooo112384.sw.export.doc.styledoesntexist.patch
- drop integrated workspace.cmcfixes77.patch
- drop integrated workspace.vcl114.patch
- drop integrated openoffice.org-3.3.0.ooo106591.sal.tradcopy.patch
- drop integrated workspace.vcl115.patch
- drop integrated workspace.cmcfixes78.patch
- drop integrated openoffice.org-3.3.0.ooo114012.sd.bada11ychain.patch
- drop integrated workspace.cmcfixes79.patch
- drop integrated openoffice.org-3.3.0.ooo114703.vcl.betterlocalize.font.patch
- drop integrated openoffice.org-3.3.0.rh638185.editeng.cjkctlhtmlsizes.patch
- drop integrated openoffice.org-3.3.0.rh637738.libgcrypt.addmutex.patch
- drop integrated openoffice.org-3.2.0.rh632236.writerfilter.cleanup-cell-props.patch
- drop workspace.gtk3.patch

* Wed Oct 06 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.1-2
- Related: rhbz#639945 pull in review changes
  + redland build-fix
  + replace awk script
  + validate .destop files

* Wed Sep 29 2010 Caolán McNamara <caolanm@redhat.com> 3.2.99.1-1
- initial import of the leviathan
